@@ -36,17 +36,15 @@
  */
 
 #include <string.h>
-#include <stdlib.h>     /* for strtod   */
-#include <math.h>       /* for HUGE_VAL */
 #include <stdio.h>
 #include <errno.h>
 #include <sys/stat.h>
-#include <sys/types.h>
 #include <utime.h>
 
 #include "nvti.h"
-#include "cvss.h"  /* for get_cvss_score_from_base_metrics */
-#include "../misc/openvas_logging.h"
+
+#undef  G_LOG_DOMAIN
+#define G_LOG_DOMAIN "lib  nvti"
 
 /**
  * @brief Create a new nvtpref structure filled with the given values.
@@ -82,7 +80,7 @@ nvtpref_new (gchar * name, gchar * type, gchar * dflt)
 /**
  * @brief Free memory of a nvtpref structure.
  *
- * @param n The structure to be freed.
+ * @param np The structure to be freed.
  */
 void
 nvtpref_free (nvtpref_t * np)
@@ -172,8 +170,6 @@ nvti_free (nvti_t * n)
     g_free (n->version);
   if (n->name)
     g_free (n->name);
-  if (n->summary)
-    g_free (n->summary);
   if (n->copyright)
     g_free (n->copyright);
   if (n->cve)
@@ -202,8 +198,7 @@ nvti_free (nvti_t * n)
     g_free (n->family);
   if (n->prefs)
     {
-      guint len = g_slist_length (n->prefs);
-      int i;
+      int i, len = g_slist_length (n->prefs);
       for (i = 0; i < len; i++)
         nvtpref_free (g_slist_nth_data (n->prefs, i));
       g_slist_free (n->prefs);
@@ -253,20 +248,6 @@ nvti_name (const nvti_t * n)
   return (n ? n->name : NULL);
 }
 
-/**
- * @brief Get the summary.
- *
- * @param n The NVT Info structure of which the name should
- *          be returned.
- *
- * @return The summary string. Don't free this.
- */
-gchar *
-nvti_summary (const nvti_t * n)
-{
-  return (n ? n->summary : NULL);
-}
-
 /**
  * @brief Get the copyright notice.
  *
@@ -567,27 +548,6 @@ nvti_set_name (nvti_t * n, const gchar * name)
   return (0);
 }
 
-/**
- * @brief Set the summary of a NVT.
- *
- * @param n The NVT Info structure.
- *
- * @param summary The summary to set. A copy will be created from this.
- *
- * @return 0 for success. Anything else indicates an error.
- */
-int
-nvti_set_summary (nvti_t * n, const gchar * summary)
-{
-  if (! n)
-    return (-1);
-
-  if (n->summary)
-    g_free (n->summary);
-  n->summary = g_strdup (summary);
-  return (0);
-}
-
 /**
  * @brief Set the copyright of a NVT.
  *
@@ -704,7 +664,7 @@ nvti_set_tag (nvti_t * n, const gchar * tag)
  *
  * @param n The NVT Info structure.
  *
- * @param tag The CVSS base to set. A copy will be created from this.
+ * @param cvss_base The CVSS base to set. A copy will be created from this.
  *
  * @return 0 for success. Anything else indicates an error.
  */
@@ -893,7 +853,7 @@ nvti_set_family (nvti_t * n, const gchar * family)
  *
  * @param n The NVT Info structure.
  *
- * @param timout The timeout to set. Values <= 0 will indicate it is not set.
+ * @param timeout The timeout to set. Values <= 0 will indicate it is not set.
  *
  * @return 0 for success. Anything else indicates an error.
  */
@@ -961,7 +921,7 @@ nvti_add_cve (nvti_t * n, const gchar * cve_id)
  *
  * @param n The NVT Info structure.
  *
- * @param cve_id The BID ID to add. A copy will be created from this.
+ * @param bid_id The BID ID to add. A copy will be created from this.
  *
  * @return 0 for success. 1 if n was NULL. 2 if bid_id was NULL.
  */
@@ -1208,7 +1168,6 @@ nvti_from_keyfile (const gchar * fn)
   set_from_key (keyfile, "OID", n, nvti_set_oid);
   set_from_key (keyfile, "Version", n, nvti_set_version);
   set_from_key (keyfile, "Name", n, nvti_set_name);
-  set_from_key (keyfile, "Summary", n, nvti_set_summary);
   set_from_key (keyfile, "Copyright", n, nvti_set_copyright);
   set_from_key (keyfile, "CVEs", n, nvti_set_cve);
   set_from_key (keyfile, "BIDs", n, nvti_set_bid);
@@ -1264,16 +1223,14 @@ nvti_from_keyfile (const gchar * fn)
 }
 
 /**
- * @brief Read NVT Info from a keyfile.
+ * @brief Set value in keyfile.
  *
  * @param keyfile Keyfile.
  * @param name    Key name.
- * @param nvti    NVTI.
  * @param value   Value.
  */
 static void
-set_from_nvti (GKeyFile *keyfile, const gchar *name, const nvti_t *nvti,
-               const gchar *value)
+set_keyfile_info (GKeyFile *keyfile, const gchar *name, const gchar *value)
 {
   if (value)
     {
@@ -1301,29 +1258,28 @@ nvti_to_keyfile (const nvti_t * n, const char *src, const gchar *fn)
   GKeyFile *keyfile = g_key_file_new ();
   gchar *text;
   GError *error = NULL;
+  unsigned int i;
 
-  set_from_nvti (keyfile, "OID", n, n->oid);
-  set_from_nvti (keyfile, "Version", n, n->version);
-  set_from_nvti (keyfile, "Name", n, n->name);
-  set_from_nvti (keyfile, "Summary", n, n->summary);
-  set_from_nvti (keyfile, "Copyright", n, n->copyright);
-  set_from_nvti (keyfile, "CVEs", n, n->cve);
-  set_from_nvti (keyfile, "BIDs", n, n->bid);
-  set_from_nvti (keyfile, "XREFs", n, n->xref);
-  set_from_nvti (keyfile, "Tags", n, n->tag);
-  set_from_nvti (keyfile, "Dependencies", n, n->dependencies);
-  set_from_nvti (keyfile, "RequiredKeys", n, n->required_keys);
-  set_from_nvti (keyfile, "MandatoryKeys", n, n->mandatory_keys);
-  set_from_nvti (keyfile, "ExcludedKeys", n, n->excluded_keys);
-  set_from_nvti (keyfile, "RequiredPorts", n, n->required_ports);
-  set_from_nvti (keyfile, "RequiredUDPPorts", n, n->required_udp_ports);
-  set_from_nvti (keyfile, "Family", n, n->family);
+  set_keyfile_info (keyfile, "OID", n->oid);
+  set_keyfile_info (keyfile, "Version", n->version);
+  set_keyfile_info (keyfile, "Name", n->name);
+  set_keyfile_info (keyfile, "Copyright", n->copyright);
+  set_keyfile_info (keyfile, "CVEs", n->cve);
+  set_keyfile_info (keyfile, "BIDs", n->bid);
+  set_keyfile_info (keyfile, "XREFs", n->xref);
+  set_keyfile_info (keyfile, "Tags", n->tag);
+  set_keyfile_info (keyfile, "Dependencies", n->dependencies);
+  set_keyfile_info (keyfile, "RequiredKeys", n->required_keys);
+  set_keyfile_info (keyfile, "MandatoryKeys", n->mandatory_keys);
+  set_keyfile_info (keyfile, "ExcludedKeys", n->excluded_keys);
+  set_keyfile_info (keyfile, "RequiredPorts", n->required_ports);
+  set_keyfile_info (keyfile, "RequiredUDPPorts", n->required_udp_ports);
+  set_keyfile_info (keyfile, "Family", n->family);
   if (n->timeout > 0)
     g_key_file_set_integer (keyfile, "NVT Info", "Timeout", n->timeout);
   if (n->category > 0)
     g_key_file_set_integer (keyfile, "NVT Info", "Category", n->category);
 
-  int i;
   for (i = 0; i < nvti_pref_len (n); i++)
     {
       const nvtpref_t *np = nvti_pref (n, i);
@@ -1338,7 +1294,7 @@ nvti_to_keyfile (const nvti_t * n, const char *src, const gchar *fn)
       lst[2] = g_convert (((nvtpref_t *) np)->dflt, -1, "UTF-8", "ISO_8859-1",
                           NULL, &size, NULL);
 
-      g_snprintf (buf, 10, "P%d", i);
+      g_snprintf (buf, 10, "P%u", i);
       g_key_file_set_string_list ((GKeyFile *) keyfile, "NVT Prefs", buf,
                                   (const gchar **) lst, 3);
 //    g_key_file_set_string_list((GKeyFile *)keyfile, "NVT Prefs", (gchar *)lst[0], (const gchar **)lst, 3);
@@ -1351,8 +1307,7 @@ nvti_to_keyfile (const nvti_t * n, const char *src, const gchar *fn)
   text = g_key_file_to_data (keyfile, NULL, &error);
   if (error != NULL)
     {
-      log_legacy_write ("Error occured while preparing %s: %s\n", fn,
-                        error->message);
+      g_warning ("Error occurred while preparing %s: %s\n", fn, error->message);
       g_error_free (error);
     }
   else
@@ -1363,8 +1318,7 @@ nvti_to_keyfile (const nvti_t * n, const char *src, const gchar *fn)
           gchar *cache_dir = g_path_get_dirname (fn);
           if ((g_mkdir_with_parents (cache_dir, 0755) < 0) && (errno != EEXIST))
             {
-              log_legacy_write ("mkdir(%s) : %s\n", cache_dir,
-                                strerror (errno));
+              g_warning ("mkdir(%s) : %s\n", cache_dir, strerror (errno));
               g_free (cache_dir);
               g_free (text);
               g_key_file_free (keyfile);
@@ -1376,7 +1330,7 @@ nvti_to_keyfile (const nvti_t * n, const char *src, const gchar *fn)
 
       if (!fp)
         {                       // again failed
-          log_legacy_write ("fopen(%s) : %s\n", fn, strerror (errno));
+          g_warning ("fopen(%s) : %s\n", fn, strerror (errno));
           g_free (text);
           g_key_file_free (keyfile);
           return (2);
@@ -1396,10 +1350,10 @@ nvti_to_keyfile (const nvti_t * n, const char *src, const gchar *fn)
               src_timestamp.actime = src_stat.st_atime;
               src_timestamp.modtime = src_stat.st_mtime;
               if (utime (fn, &src_timestamp) != 0)
-                log_legacy_write ("utime(%s) : %s\n", fn, strerror (errno));
+                g_warning ("utime(%s) : %s\n", fn, strerror (errno));
             }
           else
-            log_legacy_write ("stat(%s) : %s\n", src, strerror (errno));
+            g_warning ("stat(%s) : %s\n", src, strerror (errno));
         }
 
       g_free (text);
