@@ -26,15 +26,9 @@
 #include "openvas_networking.h"
 
 #include <fcntl.h>
+#include <unistd.h>
 #include <glib/gstdio.h>
 
-#include <libssh/libssh.h>
-#include <gnutls/x509.h>
-
-#if GLIB_CHECK_VERSION (2, 30, 0)
-#include <stdlib.h>  /* for mkdtemp () */
-#endif
-
  /* Global variables */
 
 /* Source interface name eg. eth1. */
@@ -176,7 +170,7 @@ openvas_source_addr6 (void *addr6)
 
 /**
  * @brief Gives the source IPv4 mapped as an IPv6 address.
- * eg. 192.168.20.10 would map to ::ffff:192.168.20.10.
+ * eg. 192.168.20.10 would map to \::ffff:192.168.20.10.
  *
  * @param[out]  addr6  Buffer of at least 16 bytes.
  */
@@ -219,7 +213,7 @@ openvas_source_addr6_str (void)
 
 /**
  * @brief Maps an IPv4 address as an IPv6 address.
- * eg. 192.168.10.20 would map to ::ffff:192.168.10.20.
+ * eg. 192.168.10.20 would map to \::ffff:192.168.10.20.
  *
  * @param[in]  ip4  IPv4 address to map.
  * @param[out] ip6  Buffer to store the IPv6 address.
@@ -496,6 +490,9 @@ port_range_ranges (const char *port_range)
   array_t *ranges;
   int tcp;
 
+  if (!port_range)
+    return NULL;
+
   ranges = make_array ();
 
   while (*port_range && isblank (*port_range)) port_range++;
@@ -592,7 +589,7 @@ port_range_ranges (const char *port_range)
 int
 port_in_port_ranges (int pnum, port_protocol_t ptype, array_t *pranges)
 {
-  int i;
+  unsigned int i;
 
   if (pranges == NULL || pnum < 0 || pnum > 65536)
     return 0;
@@ -609,126 +606,17 @@ port_in_port_ranges (int pnum, port_protocol_t ptype, array_t *pranges)
 }
 
 /**
- * @brief Decrypts a base64 encrypted ssh private key.
+ * @brief Checks if IPv6 support is enabled.
  *
- * @param[in]   pkcs8_key       PKCS#8 encrypted private key.
- * @param[in]   passphrase      Passphrase for the private key.
- *
- * @return Decrypted private key if success, NULL otherwise.
+ * @return 1 if IPv6 is enabled, 0 if disabled.
  */
-char *
-openvas_ssh_pkcs8_decrypt (const char *pkcs8_key, const char *passphrase)
+int
+ipv6_is_enabled ()
 {
-  gnutls_datum_t data;
-  gnutls_x509_privkey_t key;
-  char buffer[16 * 2048];
-  int rc;
-  size_t size = sizeof (buffer);
+  int sock = socket (PF_INET6, SOCK_STREAM, 0);
 
-  rc = gnutls_x509_privkey_init (&key);
-  if (rc)
-    return NULL;
-  data.size = strlen (pkcs8_key);
-  data.data = (void *) g_strdup (pkcs8_key);
-  rc = gnutls_x509_privkey_import_pkcs8 (key, &data, GNUTLS_X509_FMT_PEM,
-                                         passphrase?: "", 0);
-  if (rc)
-    {
-      gnutls_x509_privkey_deinit (key);
-      return NULL;
-    }
-  g_free (data.data);
-  rc = gnutls_x509_privkey_export (key, GNUTLS_X509_FMT_PEM, buffer, &size);
-  gnutls_x509_privkey_deinit (key);
-  if (rc)
-    return NULL;
-  return g_strdup (buffer);
-}
-
-/**
- * @brief Exports a base64 encoded public key from a private key and its
- *        passphrase.
- *
- * @param[in]   private_key     Private key to export.
- * @param[in]   passphrase      Passphrase for the private key.
- *
- * @return Allocated base64 encoded public key if success, NULL otherwise.
- */
-char *
-openvas_ssh_public_from_private (const char *private_key, const char *passphrase)
-{
-#if LIBSSH_VERSION_INT >= SSH_VERSION_INT (0, 6, 0)
-  ssh_key priv;
-  char *pub_key, *decrypted_priv, *pub_str = NULL;
-  const char *type;
-  int ret;
-
-  decrypted_priv = openvas_ssh_pkcs8_decrypt (private_key, passphrase);
-  ret = ssh_pki_import_privkey_base64
-         (decrypted_priv ?: private_key, passphrase, NULL, NULL, &priv);
-  g_free (decrypted_priv);
-  if (ret)
-    return NULL;
-  ret = ssh_pki_export_pubkey_base64 (priv, &pub_key);
-  type = ssh_key_type_to_char (ssh_key_type (priv));
-#if LIBSSH_VERSION_INT >= SSH_VERSION_INT (0, 6, 4)
-  if (!strcmp (type, "ssh-ecdsa"))
-    type = ssh_pki_key_ecdsa_name (priv);
-#endif
-  ssh_key_free (priv);
-  if (ret)
-    return NULL;
-  pub_str = g_strdup_printf ("%s %s", type, pub_key);
-  g_free (pub_key);
-  return pub_str;
-
-#else
-  char key_dir[] = "/tmp/openvas_key_XXXXXX", *base64, *data;
-  char filename[1024], *decrypted_priv;
-  ssh_private_key ssh_privkey;
-  ssh_public_key ssh_pubkey;
-  ssh_session session;
-  ssh_string sstring;
-  size_t datalen;
-
-#if GLIB_CHECK_VERSION (2, 30, 0)
-  if (!private_key || !g_mkdtemp_full (key_dir, S_IRUSR|S_IWUSR|S_IXUSR))
-#else
-  if (!private_key || !mkdtemp (key_dir))
-#endif
-    return NULL;
-  g_snprintf (filename, sizeof (filename), "%s/key.tmp", key_dir);
-  decrypted_priv = openvas_ssh_pkcs8_decrypt (private_key, passphrase);
-  if (!g_file_set_contents (filename, decrypted_priv ?: private_key, -1, NULL))
-    {
-      g_free (decrypted_priv);
-      g_rmdir (key_dir);
-      return NULL;
-    }
-  g_free (decrypted_priv);
-  session = ssh_new ();
-  ssh_privkey = privatekey_from_file (session, filename, 0, passphrase);
-  ssh_free (session);
-  g_remove (filename);
-  g_rmdir (key_dir);
-  if (!ssh_privkey)
-    return NULL;
-  /* Return as base64 encoded public key. */
-  ssh_pubkey = publickey_from_privatekey (ssh_privkey);
-  privatekey_free (ssh_privkey);
-  if (!ssh_pubkey)
-    return NULL;
-  sstring = publickey_to_string (ssh_pubkey);
-  publickey_free (ssh_pubkey);
-  if (!sstring)
-    return NULL;
-  data = ssh_string_to_char (sstring);
-  datalen = ssh_string_len (sstring);
-  /* LibSSH 0.5 supports ssh-rsa only. */
-  base64 = g_strdup_printf ("ssh-rsa %s",
-                            g_base64_encode ((guchar *) data, datalen));
-  ssh_string_free (sstring);
-  g_free (data);
-  return base64;
-#endif
+  if (sock == -1 && errno == EAFNOSUPPORT)
+    return 0;
+  close (sock);
+  return 1;
 }
