@@ -45,7 +45,7 @@
 #include <gnutls/x509.h>
 
 #include "network.h"            /* for socket_close() */
-#include "kb.h"                 /* for kb_item_get_str() */
+#include "../base/kb.h"         /* for kb_item_get_str() */
 
 #include "ids_send.h"
 #include "prefs.h"
@@ -115,13 +115,9 @@ struct csc_hook_s
  */
 static struct csc_hook_s *csc_hooks;
 
-
-static void my_gnutls_transport_set_lowat_default (gnutls_session_t session);
-
-
 
 /**
- * OPENVAS_STREAM(x) is TRUE if <x> is a OpenVAS-ified fd
+ * OPENVAS_STREAM(x) is TRUE if \<x\> is a OpenVAS-ified fd
  */
 #define OPENVAS_STREAM(x) (((x - OPENVAS_FD_OFF) < OPENVAS_FD_MAX) && ((x - OPENVAS_FD_OFF) >=0))
 
@@ -590,9 +586,22 @@ cleanup:
   return result;
 }
 
+static int
+is_ip_address (const char *str)
+{
+  struct sockaddr_in sa;
+  struct sockaddr_in6 sa6;
+
+  if (inet_pton (AF_INET, str, &(sa.sin_addr)) == 1)
+    return 1;
+
+  return inet_pton (AF_INET6, str, &(sa6.sin6_addr)) == 1;
+}
+
 static int
 open_SSL_connection (openvas_connection * fp, const char *cert,
-                     const char *key, const char *passwd, const char *cafile)
+                     const char *key, const char *passwd, const char *cafile,
+                     const char *hostname)
 {
   int ret, err, d;
   time_t tictac;
@@ -616,6 +625,10 @@ open_SSL_connection (openvas_connection * fp, const char *cert,
   if (set_gnutls_protocol (fp->tls_session, fp->transport, fp->priority) < 0)
     return -1;
 
+  if (hostname && !is_ip_address (hostname))
+    gnutls_server_name_set (fp->tls_session, GNUTLS_NAME_DNS, hostname,
+                            strlen (hostname));
+
   ret = gnutls_certificate_allocate_credentials (&(fp->tls_cred));
   if (ret < 0)
     {
@@ -663,7 +676,8 @@ open_SSL_connection (openvas_connection * fp, const char *cert,
       if (err == 0)
         return 1;
 
-      if (err != GNUTLS_E_INTERRUPTED && err != GNUTLS_E_AGAIN)
+      if (err != GNUTLS_E_INTERRUPTED && err != GNUTLS_E_AGAIN
+          && err != GNUTLS_E_WARNING_ALERT_RECEIVED)
         {
 #ifdef DEBUG_SSL
           tlserror ("gnutls_handshake", err);
@@ -762,7 +776,10 @@ int
 socket_negotiate_ssl (int fd, openvas_encaps_t transport, struct arglist *args)
 {
   char *cert = NULL, *key = NULL, *passwd = NULL, *cafile = NULL;
+  char *hostname = NULL;
   openvas_connection *fp;
+  kb_t kb;
+  char buf[1024];
 
   if (!fd_is_stream (fd))
     {
@@ -770,14 +787,18 @@ socket_negotiate_ssl (int fd, openvas_encaps_t transport, struct arglist *args)
       return -1;
     }
   fp = OVAS_CONNECTION_FROM_FD(fd);
-  cert = kb_item_get_str (plug_get_kb (args), "SSL/cert");
-  key = kb_item_get_str (plug_get_kb (args), "SSL/key");
-  passwd = kb_item_get_str (plug_get_kb (args), "SSL/password");
-  cafile = kb_item_get_str (plug_get_kb (args), "SSL/CA");
+  kb = plug_get_kb (args);
+  cert = kb_item_get_str (kb, "SSL/cert");
+  key = kb_item_get_str (kb, "SSL/key");
+  passwd = kb_item_get_str (kb, "SSL/password");
+  cafile = kb_item_get_str (kb, "SSL/CA");
+  snprintf (buf, sizeof (buf), "Host/SNI/%d/force_disable", fp->port);
+  if (kb_item_get_int (kb, buf) <= 0)
+    hostname = plug_get_host_fqdn (args);
 
   fp->transport = transport;
   fp->priority = NULL;
-  if (open_SSL_connection (fp, cert, key, passwd, cafile) <= 0)
+  if (open_SSL_connection (fp, cert, key, passwd, cafile, hostname) <= 0)
     {
       log_legacy_write ("socket_negotiate_ssl: SSL connection failed.\n");
       release_connection_fd (fd, 0);
@@ -933,11 +954,6 @@ socket_get_ssl_compression (int fd)
         return 0;
       case GNUTLS_COMP_DEFLATE:
         return 1;
-#ifdef GNUTLS_COMP_LZO
-      /* LZO compression was removed in GnuTLS >= 3.0.0 */
-      case GNUTLS_COMP_LZO:
-        return 2;
-#endif
       default:
         return -1;
     }
@@ -999,6 +1015,7 @@ open_stream_connection_ext (struct arglist *args, unsigned int port,
   char *key = NULL;
   char *passwd = NULL;
   char *cafile = NULL;
+  char *hostname = NULL;
 
   if (!priority)
     priority = ""; /* To us an empty string is equivalent to NULL.  */
@@ -1056,9 +1073,11 @@ open_stream_connection_ext (struct arglist *args, unsigned int port,
   if (fp->fd < 0)
     goto failed;
 
+  kb_t kb = plug_get_kb (args);
   switch (transport)
     {
     int ret;
+    char buf[1024];
     case OPENVAS_ENCAPS_IP:
       break;
     case OPENVAS_ENCAPS_SSLv23:
@@ -1068,17 +1087,20 @@ open_stream_connection_ext (struct arglist *args, unsigned int port,
     case OPENVAS_ENCAPS_TLSv12:
     case OPENVAS_ENCAPS_TLScustom:
       renice_myself ();
-      cert = kb_item_get_str (plug_get_kb (args), "SSL/cert");
-      key = kb_item_get_str (plug_get_kb (args), "SSL/key");
-      passwd = kb_item_get_str (plug_get_kb (args), "SSL/password");
+      cert = kb_item_get_str (kb, "SSL/cert");
+      key = kb_item_get_str (kb, "SSL/key");
+      passwd = kb_item_get_str (kb, "SSL/password");
 
-      cafile = kb_item_get_str (plug_get_kb (args), "SSL/CA");
+      cafile = kb_item_get_str (kb, "SSL/CA");
 
       /* fall through */
 
     case OPENVAS_ENCAPS_SSLv2:
       /* We do not need a client certificate in this case */
-      ret = open_SSL_connection (fp, cert, key, passwd, cafile);
+      snprintf (buf, sizeof (buf), "Host/SNI/%d/force_disable", fp->port);
+      if (kb_item_get_int (kb, buf) <= 0)
+        hostname = plug_get_host_fqdn (args);
+      ret = open_SSL_connection (fp, cert, key, passwd, cafile, hostname);
       g_free (cert);
       g_free (key);
       g_free (passwd);
@@ -1136,194 +1158,6 @@ open_stream_auto_encaps_ext (struct arglist *args, unsigned int port,
  /*NOTREACHED*/
 }
 
-/*
- * Scanner socket functions
- */
-
-struct ovas_scanner_context_s
-{
-  /** Transport encapsulation to use */
-  openvas_encaps_t encaps;
-
-  /** GnuTLS credentials */
-  gnutls_certificate_credentials_t tls_cred;
-
-  /** GnuTLS priority string */
-  char *priority;
-
-  gnutls_session_t tls_session;
-};
-
-
-/**
- * @brief Creates a new ovas_scanner_context_t.
- *
- * If any of the SSL encapsulations are used, the parameters certfile, keyfile,
- * and cafile should be the filenames of the scanner certificate and
- * corresponding key and the CA certificate.  The optional passwd parameter is
- * used as the password to decrypt the keyfile if it is encrypted.
- */
-ovas_scanner_context_t
-ovas_scanner_context_new (openvas_encaps_t encaps, const char *certfile,
-                          const char *keyfile, const char *passwd,
-                          const char *cafile, const char *priority,
-                          const char *dhparams)
-{
-  ovas_scanner_context_t ctx = NULL;
-
-  ctx = g_malloc0 (sizeof (*ctx));
-  ctx->encaps = encaps;
-  ctx->priority = g_strdup (priority);
-
-  if (ctx->encaps != OPENVAS_ENCAPS_IP)
-    {
-      int ret = gnutls_certificate_allocate_credentials (&(ctx->tls_cred));
-      if (ret < 0)
-        {
-          tlserror ("gnutls_certificate_allocate_credentials", ret);
-          ctx->tls_cred = NULL;
-          goto fail;
-        }
-
-      if (certfile && keyfile)
-        {
-          if (load_cert_and_key (ctx->tls_cred, certfile, keyfile, passwd) < 0)
-            goto fail;
-        }
-
-      if (cafile != NULL)
-        {
-          ret =
-            gnutls_certificate_set_x509_trust_file (ctx->tls_cred, cafile,
-                                                    GNUTLS_X509_FMT_PEM);
-          if (ret < 0)
-            {
-              tlserror ("gnutls_certificate_set_x509_trust_file", ret);
-              goto fail;
-            }
-        }
-      if (dhparams && set_gnutls_dhparams (ctx->tls_cred, dhparams))
-        log_legacy_write ("Couldn't set DH parameters from %s\n", dhparams);
-    }
-
-  return ctx;
-
-
-fail:
-  ovas_scanner_context_free (ctx);
-  return NULL;
-}
-
-
-/**
- * @brief Frees the ovas_scanner_context_t instance ctx.
- *
- * If ctx is NULL, nothing is done.
- *
- * @param ctx ovas_scanner_context_t to free.
- */
-void
-ovas_scanner_context_free (ovas_scanner_context_t ctx)
-{
-  if (ctx == NULL)
-    return;
-
-  if (ctx->tls_cred != NULL)
-    gnutls_certificate_free_credentials (ctx->tls_cred);
-
-  g_free (ctx->priority);
-  g_free (ctx);
-}
-
-/**
- * @brief Sets up SSL/TLS on the socket soc and returns a openvas file
- * @brief descriptor.
- *
- * The parameters for the SSL/TLS layer are taken from ctx.
- * Afterwards, the credentials of ctx are also referenced by the SSL/TLS
- * objects associated with the openvas file descriptor.  This means that
- * the context ctx must not be freed until the openvas file descriptor is
- * closed.
- *
- * @return The openvas file descriptor on success and -1 on failure.
- */
-int
-ovas_scanner_context_attach (ovas_scanner_context_t ctx, int soc)
-{
-  int fd;
-  openvas_connection *fp = NULL;
-  int ret;
-
-  fd = openvas_register_connection (soc, NULL, NULL, ctx->encaps);
-  if (fd < 0)
-    return -1;
-
-  fp = OVAS_CONNECTION_FROM_FD (fd);
-
-  if (fp->transport != OPENVAS_ENCAPS_IP)
-    {
-      ret = gnutls_init (&(fp->tls_session), GNUTLS_SERVER);
-      if (ret < 0)
-        {
-          tlserror ("gnutls_init", ret);
-          goto fail;
-        }
-      ctx->tls_session = fp->tls_session;
-      my_gnutls_transport_set_lowat_default (fp->tls_session);
-
-      ret = set_gnutls_protocol (fp->tls_session, fp->transport, ctx->priority);
-      if (ret < 0)
-        goto fail;
-
-      if (ctx->tls_cred)
-        {
-          /* *fp contains a field for the gnutls credentials.  We do not
-           * set it here because ctx->tls_cred is owned by ctx and
-           * copying it to fp->tls_cred would lead to it being freed
-           * when the connection is closed. */
-          ret =
-            gnutls_credentials_set (fp->tls_session, GNUTLS_CRD_CERTIFICATE,
-                                    ctx->tls_cred);
-          if (ret < 0)
-            {
-              tlserror ("gnutls_credentials_set", ret);
-              return -1;
-            }
-        }
-
-
-      /* request client certificate if any. */
-      gnutls_certificate_server_set_request (fp->tls_session,
-                                             GNUTLS_CERT_REQUIRE);
-
-      gnutls_transport_set_ptr (fp->tls_session,
-                                (gnutls_transport_ptr_t)
-                                GSIZE_TO_POINTER (fp->fd));
-    retry:
-      ret = gnutls_handshake (fp->tls_session);
-      if (ret < 0)
-        {
-          if (ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED)
-            goto retry;
-#ifdef DEBUG_SSL
-          tlserror ("gnutls_handshake", ret);
-#endif
-          goto fail;
-        }
-
-      if (openvas_server_verify (fp->tls_session))
-        {
-          goto fail;
-        }
-    }
-
-  return fd;
-
-fail:
-  release_connection_fd (fd, 0);
-  return -1;
-}
-
 int
 stream_set_timeout (int fd, int timeout)
 {
@@ -1920,7 +1754,7 @@ get_encaps_name (openvas_encaps_t code)
     case OPENVAS_ENCAPS_TLScustom:
       return "TLScustom";
     default:
-      snprintf (str, sizeof (str), "[unknown transport layer - code %d (0x%x)]", code, code);   /* RATS: ignore */
+      snprintf (str, sizeof (str), "[unknown transport layer - code %d (0x%x)]", code, code);
       return str;
     }
 }
@@ -1942,7 +1776,7 @@ get_encaps_through (openvas_encaps_t code)
     case OPENVAS_ENCAPS_TLScustom:
       return " through SSL";
     default:
-      snprintf (str, sizeof (str), " through unknown transport layer - code %d (0x%x)", code, code);    /* RATS: ignore */
+      snprintf (str, sizeof (str), " through unknown transport layer - code %d (0x%x)", code, code);
       return str;
     }
 }
@@ -2186,11 +2020,13 @@ open_sock_option (struct arglist *args, unsigned int port, int type,
 int
 recv_line (int soc, char *buf, size_t bufsiz)
 {
-  int n, ret = 0;
+  int n;
+  unsigned int ret = 0;
 
   /* Dirty SSL hack */
   if (OPENVAS_STREAM (soc))
     {
+      unsigned int ret = 0;
       buf[0] = '\0';
 
       do
@@ -2240,7 +2076,7 @@ recv_line (int soc, char *buf, size_t bufsiz)
           errno = 0;
           FD_ZERO (&rd);
           FD_SET (soc, &rd);
-          tv.tv_sec = 5;
+          tv.tv_sec = 30;
           tv.tv_usec = 0;
           e = select (soc + 1, &rd, NULL, NULL, &tv);
           if (e == 0 && !FD_ISSET (soc, &rd))
@@ -2473,7 +2309,7 @@ internal_send (int soc, char *data, int msg_type)
  * internal_send() / internal_recv() :
  *
  * When processes are passing messages to each other, the format is
- * <length><msg>, with <length> being a long integer. The functions
+ * \<length\>\<msg\>, with \<length\> being a long integer. The functions
  * internal_send() and internal_recv() encapsulate and decapsulate
  * the messages themselves.
  *
@@ -2703,15 +2539,46 @@ getpts (char *origexpr, int *len)
   return tmp;
 }
 
-/* GnuTLS 2.11.1 changed the semantics of set_lowat and 2.99.0 removed
-   that function.  As a quick workaround we set it back to the old
-   default.  gcc 4.4 has no diagnostic push pragma, thus we better put
-   this function at the end of the file.  */
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-static void
-my_gnutls_transport_set_lowat_default (gnutls_session_t session)
+/**
+ * @brief Initializes a host_info.
+ *
+ * @param[in]   name        Hostname.
+ * @param[in]   ip          IP address.
+ * @param[in]   vhosts      Vhosts list.
+ * @param[in]   fqdn        Fully qualified domain name.
+ *
+ * @return host_info pointer.
+ */
+struct host_info *
+host_info_init (const char *name, const struct in6_addr *ip,
+                const char *vhosts, const char *fqdn)
 {
-#if GNUTLS_VERSION_NUMBER < 0x026300
-  gnutls_transport_set_lowat (session, 1);
-#endif
+  struct host_info *hostinfo;
+
+  hostinfo = g_malloc0 (sizeof (struct host_info));
+  hostinfo->name = g_strdup (name);
+  hostinfo->fqdn = g_strdup (fqdn);
+  hostinfo->vhosts = g_strdup (vhosts);
+  if (ip)
+    {
+      hostinfo->ip = g_malloc0 (sizeof (struct in6_addr));
+      memcpy (hostinfo->ip, ip, sizeof (struct in6_addr));
+    }
+  return hostinfo;
+}
+
+/**
+ * @brief Free a host_info struct.
+ *
+ * @param[in]   hostinfo    Host info to free.
+ */
+void
+host_info_free (struct host_info *hostinfo)
+{
+  if (!hostinfo)
+    return;
+  g_free (hostinfo->name);
+  g_free (hostinfo->fqdn);
+  g_free (hostinfo->vhosts);
+  g_free (hostinfo->ip);
 }
