@@ -29,6 +29,8 @@
 
 #include "openvas_proctitle.h"
 
+extern const char *__progname;
+extern const char *__progname_full;
 static int argv_len;
 static char **old_argv;
 extern char **environ;
@@ -45,12 +47,17 @@ proctitle_init (int argc, char **argv)
 {
   int i = 0;
   char **envp = environ;
+  char *new_progname, *new_progname_full;
 
   if (argv == NULL)
     return;
+
+  new_progname = strdup (__progname);
+  new_progname_full = strdup (__progname_full);
+
   /* Move environ to new memory, to be able to reuse older one. */
   while (envp[i]) i++;
-  environ = g_malloc0 (sizeof(char *) * (i + 1));
+  environ = g_malloc0 (sizeof (char *) * (i + 1));
   if (current_environ)
     g_free (current_environ);
   current_environ = environ;
@@ -60,9 +67,14 @@ proctitle_init (int argc, char **argv)
 
   old_argv = argv;
   if (i > 0)
-    argv_len = envp[i-1] + strlen(envp[i-1]) - old_argv[0];
+    argv_len = envp[i-1] + strlen (envp[i-1]) - old_argv[0];
   else
-    argv_len = old_argv[argc-1] + strlen(old_argv[argc-1]) - old_argv[0];
+    argv_len = old_argv[argc-1] + strlen (old_argv[argc-1]) - old_argv[0];
+
+  /* Seems like these are in the moved environment, so reset them.  Idea from
+   * proctitle.cpp in KDE libs.  */
+  __progname = new_progname;
+  __progname_full = new_progname_full;
 }
 
 /**
