@@ -88,9 +88,64 @@ static int server_new_internal (unsigned int, const char *,
                                 const gchar *, const gchar *,
                                 gnutls_session_t *,
                                 gnutls_certificate_credentials_t *);
-static void my_gnutls_transport_set_lowat_default (gnutls_session_t);
 
 
+
+/* Connections. */
+
+/**
+ * @brief Close UNIX socket connection.
+ *
+ * @param[in]  client_connection  Client connection.
+ *
+ * @return 0 success, -1 error.
+ */
+static int
+close_unix (openvas_connection_t *client_connection)
+{
+  /* Turn off blocking. */
+  if (fcntl (client_connection->socket, F_SETFL, O_NONBLOCK) == -1)
+    {
+      g_warning ("%s: failed to set server socket flag: %s\n", __FUNCTION__,
+                 strerror (errno));
+      return -1;
+    }
+
+  if (shutdown (client_connection->socket, SHUT_RDWR) == -1)
+    {
+      if (errno == ENOTCONN)
+        return 0;
+      g_warning ("%s: failed to shutdown server socket: %s\n", __FUNCTION__,
+                 strerror (errno));
+      return -1;
+    }
+
+  if (close (client_connection->socket) == -1)
+    {
+      g_warning ("%s: failed to close server socket: %s\n", __FUNCTION__,
+                 strerror (errno));
+      return -1;
+    }
+
+  return 0;
+}
+
+/**
+ * @brief Free connection.
+ *
+ * @param[in]  client_connection  Connection.
+ */
+void
+openvas_connection_free (openvas_connection_t *client_connection)
+{
+  if (client_connection->tls)
+    openvas_server_free (client_connection->socket,
+                         client_connection->session,
+                         client_connection->credentials);
+  else
+    close_unix (client_connection);
+}
+
 
 /* Certificate verification. */
 
@@ -147,8 +202,8 @@ openvas_server_verify (gnutls_session_t session)
 /**
  * @brief Loads a file's data into gnutls_datum_t struct.
  *
- * @param[in]   file        File to load.
- * @param[out]  load_file   Destination to load file into.
+ * @param[in]   file          File to load.
+ * @param[out]  loaded_file   Destination to load file into.
  *
  * @return 0 if success, -1 if error.
  */
@@ -231,6 +286,11 @@ client_cert_callback (gnutls_session_t session,
   static gnutls_x509_crt_t crt;
   static gnutls_x509_privkey_t key;
 
+  (void) session;
+  (void) req_ca_rdn;
+  (void) nreqs;
+  (void) sign_algos;
+  (void) sign_algos_length;
   data.data = (unsigned char *) g_strdup (get_cert_pub_mem ());
   data.size = strlen (get_cert_pub_mem ());
   gnutls_x509_crt_init (&crt);
@@ -254,10 +314,24 @@ client_cert_callback (gnutls_session_t session,
   return 0;
 }
 
+/**
+ * @brief Connect to the server using a given host, port and cert.
+ *
+ * @param[in]  session   Pointer to GNUTLS session.
+ * @param[in]  host      Host to connect to.
+ * @param[in]  port      Port to connect to.
+ * @param[in]  ca_mem    CA cert.
+ * @param[in]  pub_mem   Public key.
+ * @param[in]  priv_mem  Private key.
+ * @param[in]  verify    Whether to verify.
+ *
+ * @return 0 on success, -1 on error.
+ */
 int
-openvas_server_open_with_cert (gnutls_session_t *session, const char *host,
-                               int port, const char *ca_mem,
-                               const char *pub_mem, const char *priv_mem)
+openvas_server_open_verify (gnutls_session_t *session, const char *host,
+                            int port, const char *ca_mem,
+                            const char *pub_mem, const char *priv_mem,
+                            int verify)
 {
   int ret;
   int server_socket;
@@ -385,12 +459,35 @@ openvas_server_open_with_cert (gnutls_session_t *session, const char *host,
         }
       return -1;
     }
-  if (ca_mem && pub_mem && priv_mem && openvas_server_verify (*session))
+  if (verify && openvas_server_verify (*session))
     return -1;
 
   return server_socket;
 }
 
+/**
+ * @brief Connect to the server using a given host, port and cert.
+ *
+ * Verify if all cert args are given.
+ *
+ * @param[in]  session   Pointer to GNUTLS session.
+ * @param[in]  host      Host to connect to.
+ * @param[in]  port      Port to connect to.
+ * @param[in]  ca_mem    CA cert.
+ * @param[in]  pub_mem   Public key.
+ * @param[in]  priv_mem  Private key.
+ *
+ * @return 0 on success, -1 on error.
+ */
+int
+openvas_server_open_with_cert (gnutls_session_t *session, const char *host,
+                               int port, const char *ca_mem,
+                               const char *pub_mem, const char *priv_mem)
+{
+  return openvas_server_open_verify (session, host, port, ca_mem, pub_mem,
+                                     priv_mem, ca_mem && pub_mem && priv_mem);
+}
+
 /**
  * @brief Connect to the server using a given host and port.
  *
@@ -420,6 +517,18 @@ openvas_server_close (int socket, gnutls_session_t session)
   return openvas_server_free (socket, session, NULL);
 }
 
+/**
+ * @brief Close a server connection and its socket.
+ *
+ * @param[in]  connection  Connection.
+ *
+ * @return 0 on success, -1 on error.
+ */
+void
+openvas_connection_close (openvas_connection_t *connection)
+{
+  openvas_connection_free (connection);
+}
 
 /**
  * @brief Connect to a server.
@@ -497,13 +606,13 @@ server_attach_internal (int socket, gnutls_session_t * session,
           continue;
         }
       if (host)
-        g_warning ("Failed to shake hands with server '%s' port %d: %s",
-                   host, port, gnutls_strerror (ret));
+        g_debug ("Failed to shake hands with server '%s' port %d: %s",
+                 host, port, gnutls_strerror (ret));
       else
-        g_warning ("Failed to shake hands with peer: %s",
-                   gnutls_strerror (ret));
+        g_debug ("Failed to shake hands with peer: %s",
+                 gnutls_strerror (ret));
       if (shutdown (socket, SHUT_RDWR) == -1)
-        g_warning ("Failed to shutdown server socket");
+        g_debug ("Failed to shutdown server socket");
 #ifndef _WIN32
       sigaction (SIGPIPE, &original_action, NULL);
 #endif
@@ -559,8 +668,7 @@ openvas_server_vsendf_internal (gnutls_session_t *session, const char *fmt,
   struct sigaction new_action, original_action;
 #endif
   char *sref, *string;
-  size_t left;
-  int rc = 0;
+  int rc = 0, left;
 
 #ifndef _WIN32
   new_action.sa_flags = 0;
@@ -581,9 +689,8 @@ openvas_server_vsendf_internal (gnutls_session_t *session, const char *fmt,
       ssize_t count;
 
       if (quiet == 0)
-        g_debug ("   send %zu from %.*s[...]",
-                 left, left < 30 ? (int) left : 30,
-                 string);
+        g_debug ("   send %d from %.*s[...]",
+                 left, left < 30 ? left : 30, string);
       count = gnutls_record_send (*session, string, left);
       if (count < 0)
         {
@@ -639,6 +746,81 @@ out:
 /**
  * @brief Send a string to the server.
  *
+ * @param[in]  socket   Socket.
+ * @param[in]  fmt      Format of string to send.
+ * @param[in]  ap       Args for fmt.
+ * @param[in]  quiet    Whether to log debug and info messages.  Useful for
+ *                      hiding passwords.
+ *
+ * @return 0 on success, 1 if server closed connection, -1 on error.
+ */
+static int
+unix_vsendf_internal (int socket, const char *fmt, va_list ap, int quiet)
+{
+#ifndef _WIN32
+  struct sigaction new_action, original_action;
+#endif
+  char *string_start, *string;
+  int rc = 0, left;
+
+#ifndef _WIN32
+  new_action.sa_flags = 0;
+  if (sigemptyset (&new_action.sa_mask))
+    // FIX warning
+    return -1;
+  new_action.sa_handler = SIG_IGN;
+  if (sigaction (SIGPIPE, &new_action, &original_action))
+    // FIX warning
+    return -1;
+#endif
+
+  left = vasprintf (&string, fmt, ap);
+  if (left == -1)
+    string = NULL;
+
+  string_start = string;
+  while (left > 0)
+    {
+      ssize_t count;
+
+      if (quiet == 0)
+        g_debug ("   send %d from %.*s[...]",
+                 left, left < 30 ? left : 30, string);
+      count = write (socket, string, left);
+      if (count < 0)
+        {
+          if (errno == EINTR || errno == EAGAIN)
+            continue;
+          g_warning ("Failed to write to server: %s", strerror (errno));
+
+#ifndef _WIN32
+          sigaction (SIGPIPE, &original_action, NULL);
+#endif
+
+          rc = -1;
+          goto out;
+        }
+      if (quiet == 0)
+        g_debug ("=> %.*s", (int) count, string);
+
+      string += count;
+      left -= count;
+    }
+  if (quiet == 0)
+    g_debug ("=> done");
+
+#ifndef _WIN32
+  sigaction (SIGPIPE, &original_action, NULL);
+#endif
+
+out:
+  g_free (string_start);
+  return rc;
+}
+
+/**
+ * @brief Send a string to the connection.
+ *
  * @param[in]  session  Pointer to GNUTLS session.
  * @param[in]  fmt      Format of string to send.
  * @param[in]  ap       Args for fmt.
@@ -647,20 +829,52 @@ out:
  *
  * @return 0 on success, 1 if server closed connection, -1 on error.
  */
+static int
+openvas_connection_vsendf_internal (openvas_connection_t *connection,
+                                    const char *fmt, va_list ap, int quiet)
+{
+  if (connection->tls)
+    return openvas_server_vsendf_internal (&connection->session, fmt, ap, quiet);
+  return unix_vsendf_internal (connection->socket, fmt, ap, quiet);
+}
+
+/**
+ * @brief Send a string to the server.
+ *
+ * @param[in]  session  Pointer to GNUTLS session.
+ * @param[in]  fmt      Format of string to send.
+ * @param[in]  ap       Args for fmt.
+ *
+ * @return 0 on success, 1 if server closed connection, -1 on error.
+ */
 int
 openvas_server_vsendf (gnutls_session_t *session, const char *fmt, va_list ap)
 {
   return openvas_server_vsendf_internal (session, fmt, ap, 0);
 }
 
+/**
+ * @brief Send a string to the server.
+ *
+ * @param[in]  connection  Connection.
+ * @param[in]  fmt         Format of string to send.
+ * @param[in]  ap          Args for fmt.
+ *
+ * @return 0 on success, 1 if server closed connection, -1 on error.
+ */
+int
+openvas_connection_vsendf (openvas_connection_t *connection, const char *fmt,
+                           va_list ap)
+{
+  return openvas_connection_vsendf_internal (connection, fmt, ap, 0);
+}
+
 /**
  * @brief Send a string to the server, refraining from logging besides warnings.
  *
  * @param[in]  session  Pointer to GNUTLS session.
  * @param[in]  fmt      Format of string to send.
  * @param[in]  ap       Args for fmt.
- * @param[in]  quiet    Whether to log debug and info messages.  Useful for
- *                      hiding passwords.
  *
  * @return 0 on success, 1 if server closed connection, -1 on error.
  */
@@ -671,6 +885,23 @@ openvas_server_vsendf_quiet (gnutls_session_t *session, const char *fmt,
   return openvas_server_vsendf_internal (session, fmt, ap, 1);
 }
 
+/**
+ * @brief Send a string to the server, refraining from logging besides warnings.
+ *
+ * @param[in]  session  Pointer to GNUTLS session.
+ * @param[in]  fmt      Format of string to send.
+ * @param[in]  ap       Args for fmt.
+ *
+ * @return 0 on success, 1 if server closed connection, -1 on error.
+ */
+int
+openvas_connection_vsendf_quiet (openvas_connection_t *connection,
+                                 const char *fmt,
+                                 va_list ap)
+{
+  return openvas_connection_vsendf_internal (connection, fmt, ap, 1);
+}
+
 /**
  * @brief Format and send a string to the server.
  *
@@ -691,6 +922,28 @@ openvas_server_sendf (gnutls_session_t * session, const char *format, ...)
   return rc;
 }
 
+/**
+ * @brief Format and send a string to the server.
+ *
+ * @param[in]  session  Pointer to GNUTLS session.
+ * @param[in]  format   printf-style format string for message.
+ *
+ * @return 0 on success, -1 on error.
+ */
+int
+openvas_connection_sendf (openvas_connection_t *connection,
+                          const char *format,
+                          ...)
+{
+  va_list ap;
+  int rc;
+
+  va_start (ap, format);
+  rc = openvas_connection_vsendf (connection, format, ap);
+  va_end (ap);
+  return rc;
+}
+
 /**
  * @brief Format and send a string to the server.
  *
@@ -711,6 +964,28 @@ openvas_server_sendf_quiet (gnutls_session_t * session, const char *format, ...)
   return rc;
 }
 
+/**
+ * @brief Format and send a string to the server.
+ *
+ * @param[in]  session  Pointer to GNUTLS session.
+ * @param[in]  format   printf-style format string for message.
+ *
+ * @return 0 on success, -1 on error.
+ */
+int
+openvas_connection_sendf_quiet (openvas_connection_t *connection,
+                                const char *format,
+                                ...)
+{
+  va_list ap;
+  int rc;
+
+  va_start (ap, format);
+  rc = openvas_connection_vsendf_quiet (connection, format, ap);
+  va_end (ap);
+  return rc;
+}
+
 /**
  * @brief Format and send an XML string to the server.
  *
@@ -736,6 +1011,32 @@ openvas_server_sendf_xml (gnutls_session_t * session, const char *format, ...)
   return rc;
 }
 
+/**
+ * @brief Format and send an XML string to the server.
+ *
+ * Escape XML in string and character args.
+ *
+ * @param[in]  connection  Connection.
+ * @param[in]  format      printf-style format string for message.
+ *
+ * @return 0 on success, -1 on error.
+ */
+int
+openvas_connection_sendf_xml (openvas_connection_t *connection,
+                              const char *format, ...)
+{
+  va_list ap;
+  gchar *msg;
+  int rc;
+
+  va_start (ap, format);
+  msg = g_markup_vprintf_escaped (format, ap);
+  rc = openvas_connection_sendf (connection, "%s", msg);
+  g_free (msg);
+  va_end (ap);
+  return rc;
+}
+
 /**
  * @brief Format and send an XML string to the server.
  *
@@ -764,6 +1065,35 @@ openvas_server_sendf_xml_quiet (gnutls_session_t * session,
   return rc;
 }
 
+/**
+ * @brief Format and send an XML string to the server.
+ *
+ * Escape XML in string and character args.
+ *
+ * Quiet version, only logs warnings.
+ *
+ * @param[in]  session  Pointer to GNUTLS session.
+ * @param[in]  format   printf-style format string for message.
+ *
+ * @return 0 on success, -1 on error.
+ */
+int
+openvas_connection_sendf_xml_quiet (openvas_connection_t *connection,
+                                    const char *format,
+                                    ...)
+{
+  va_list ap;
+  gchar *msg;
+  int rc;
+
+  va_start (ap, format);
+  msg = g_markup_vprintf_escaped (format, ap);
+  rc = openvas_connection_sendf_quiet (connection, "%s", msg);
+  g_free (msg);
+  va_end (ap);
+  return rc;
+}
+
 static int
 server_new_gnutls_init (gnutls_certificate_credentials_t *server_credentials)
 {
@@ -798,22 +1128,20 @@ server_new_gnutls_set (unsigned int end_type, const char *priority,
       return -1;
     }
 
-  my_gnutls_transport_set_lowat_default (*server_session);
-
   /* Depending on gnutls version different priority strings are
      possible. At least from 3.0 this is an option:
      "NONE:+VERS-TLS1.0:+CIPHER-ALL:+COMP-ALL:+RSA:+DHE-RSA:+DHE-DSS:+MAC-ALL"
      But in fact this function is only for OpenVAS internal
      purposes, not for scanning abilities. So, the conservative "NORMAL"
-     is choosen.
+     is chosen.
   */
 
   if ((err_gnutls = gnutls_priority_set_direct (*server_session,
-                                                priority? priority : "NORMAL",
+                                                priority ? priority : "NORMAL",
                                                 NULL)))
     {
       g_warning ("%s: failed to set tls priorities: %s\n", __FUNCTION__,
-                 gnutls_strerror(err_gnutls));
+                 gnutls_strerror (err_gnutls));
       gnutls_deinit (*server_session);
       return -1;
     }
@@ -835,10 +1163,10 @@ server_new_gnutls_set (unsigned int end_type, const char *priority,
 /**
  * @brief Make a session for connecting to a server.
  *
- * @param[in]   end_type            Connecton end type (GNUTLS_SERVER or
+ * @param[in]   end_type            Connection end type (GNUTLS_SERVER or
  *                                  GNUTLS_CLIENT).
  * @param[in]   priority            Custom priority string or NULL.
- * @param[in]   ca_file             Certificate authority file.
+ * @param[in]   ca_cert_file        Certificate authority file.
  * @param[in]   cert_file           Certificate file.
  * @param[in]   key_file            Key file.
  * @param[out]  server_session      The session with the server.
@@ -892,9 +1220,9 @@ server_new_internal (unsigned int end_type, const char *priority,
 /**
  * @brief Make a session for connecting to a server.
  *
- * @param[in]   end_type            Connecton end type (GNUTLS_SERVER or
+ * @param[in]   end_type            Connection end type (GNUTLS_SERVER or
  *                                  GNUTLS_CLIENT).
- * @param[in]   ca_file             Certificate authority file.
+ * @param[in]   ca_cert_file        Certificate authority file.
  * @param[in]   cert_file           Certificate file.
  * @param[in]   key_file            Key file.
  * @param[out]  server_session      The session with the server.
@@ -1072,8 +1400,8 @@ openvas_server_free (int server_socket, gnutls_session_t server_session,
         }
       if (ret)
         {
-          g_warning ("   Failed to gnutls_bye: %s\n",
-                     gnutls_strerror ((int) ret));
+          g_debug ("   Failed to gnutls_bye: %s\n",
+                   gnutls_strerror ((int) ret));
           /* Carry on successfully anyway, as this often fails, perhaps
            * because the server is closing the connection first. */
           break;
@@ -1126,17 +1454,3 @@ openvas_server_free (int server_socket, gnutls_session_t server_session,
 
   return 0;
 }
-
-
-/* GnuTLS 2.11.1 changed the semantics of set_lowat and 2.99.0 removed
-   that function.  As a quick workaround we set it back to the old
-   default.  gcc 4.4 has no diagnostic push pragma, thus we better put
-   this function at the end of the file.  */
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-static void
-my_gnutls_transport_set_lowat_default (gnutls_session_t session)
-{
-#if GNUTLS_VERSION_NUMBER < 0x026300
-  gnutls_transport_set_lowat (session, 1);
-#endif
-}
