@@ -42,6 +42,7 @@ extern "C"
 #endif
 #endif
 
+#include <glib.h>
 #include <stdarg.h>
 #include <gnutls/gnutls.h>
 #include <gnutls/x509.h>
@@ -51,13 +52,40 @@ extern "C"
 #include <netinet/ip.h>
 #endif
 
+/**
+ * @brief Connection.
+ */
+typedef struct
+{
+  int tls;                     ///< Whether uses TCP-TLS (vs UNIX socket).
+  int socket;                  ///< Socket.
+  gnutls_session_t session;                      ///< Session.
+  gnutls_certificate_credentials_t credentials;  ///< Credentials.
+  gchar *username;              ///< Username with which to connect.
+  gchar *password;              ///< Password for user with which to connect.
+  gchar *host_string;           ///< Server host string.
+  gchar *port_string;           ///< Server port string.
+  gint port;                    ///< Port of server.
+  gboolean use_certs;           ///< Whether to use certs.
+  gchar *ca_cert;               ///< CA certificate.
+  gchar *pub_key;               ///< The public key.
+  gchar *priv_key;              ///< The private key.
+} openvas_connection_t;
+
+void openvas_connection_free (openvas_connection_t *);
+
+void openvas_connection_close (openvas_connection_t *);
+
 int openvas_server_verify (gnutls_session_t);
 
 int openvas_server_open (gnutls_session_t *, const char *, int);
 
-int
-openvas_server_open_with_cert (gnutls_session_t *, const char *, int,
-                               const char *, const char *, const char *);
+int openvas_server_open_verify (gnutls_session_t *, const char *, int,
+                                const char *, const char *, const char *,
+                                int);
+
+int openvas_server_open_with_cert (gnutls_session_t *, const char *, int,
+                                   const char *, const char *, const char *);
 
 int openvas_server_close (int, gnutls_session_t);
 
@@ -65,13 +93,20 @@ int openvas_server_connect (int, struct sockaddr_in *, gnutls_session_t *);
 
 int openvas_server_attach (int, gnutls_session_t *);
 
-int openvas_server_sendf (gnutls_session_t *, const char *, ...);
+int openvas_server_sendf (gnutls_session_t *, const char *, ...)
+    __attribute__ ((format (printf, 2, 3)));
 
 int openvas_server_vsendf (gnutls_session_t *, const char *, va_list);
 
 int openvas_server_sendf_xml (gnutls_session_t *, const char *, ...);
 int openvas_server_sendf_xml_quiet (gnutls_session_t *, const char *, ...);
 
+int openvas_connection_sendf_xml (openvas_connection_t *, const char *, ...);
+int openvas_connection_sendf_xml_quiet (openvas_connection_t *, const char *,
+                                        ...);
+
+int openvas_connection_sendf (openvas_connection_t *, const char *, ...);
+
 int openvas_server_new (unsigned int, gchar *, gchar *, gchar *,
                         gnutls_session_t *, gnutls_certificate_credentials_t *);
 
