@@ -488,7 +488,6 @@ get_random_bytes (void *buf, int numbytes)
   int tmp;
   struct timeval tv;
   FILE *fp = NULL;
-  int i;
   short *iptr;
 
   if (numbytes < 0 || numbytes > 0xFFFF)
@@ -511,13 +510,15 @@ get_random_bytes (void *buf, int numbytes)
         }
       if (!fp)
         {
+          unsigned int i;
+
           if (badrandomwarning == 0)
             {
               badrandomwarning++;
             }
           /* Seed our random generator */
           gettimeofday (&tv, NULL);
-          srand ((tv.tv_sec ^ tv.tv_usec) ^ getpid ()); /* RATS: ignore */
+          srand ((tv.tv_sec ^ tv.tv_usec) ^ getpid ());
 
           for (i = 0; i < sizeof (bytebuf) / sizeof (short); i++)
             {
