@@ -41,7 +41,6 @@
 #include <glib.h>
 
 #include "arglists.h"
-#include "kb.h"
 #include "network.h"
 #include "plugutils.h"
 #include "internal_com.h"
@@ -49,6 +48,7 @@
 #include "prefs.h"             /* for prefs_get_bool */
 
 #include "../base/nvticache.h" /* for nvticache_get_by_oid() */
+#include "../base/kb.h"
 
 /* Used to allow debugging for openvas-nasl */
 int global_nasl_debug = 0;
@@ -103,79 +103,10 @@ plug_set_dep (struct arglist *desc, const char *depname)
 }
 
 void
-plug_set_launch (struct arglist *desc, int launch)
-{
-  if (arg_set_value (desc, "ENABLED", GSIZE_TO_POINTER (launch)))
-    arg_add_value (desc, "ENABLED", ARG_INT, GSIZE_TO_POINTER (launch));
-}
-
-
-int
-plug_get_launch (struct arglist *desc)
-{
-  return arg_get_value_int (desc, "ENABLED");
-}
-
-void
-_add_plugin_preference (const char *p_name,
-                        const char *name, const char *type, const char *defaul)
-{
-  char *pref;
-  char *cname;
-  int len;
-
-  if (!p_name)
-    return;
-
-  cname = g_strdup (name);
-  len = strlen (cname);
-  // Terminate string before last trailing space
-  while (cname[len - 1] == ' ')
-    {
-      cname[len - 1] = '\0';
-      len--;
-    }
-
-  pref = g_strdup_printf ("%s[%s]:%s", p_name, type, cname);
-  prefs_set (pref, defaul);
-
-  g_free (cname);
-  g_free (pref);
-}
-
-/**
- * @brief Returns a (plugin) arglist assembled from the nvti.
- *
- * @param nvti NVT Information to be used for the creation.
- *
- * @return Pointer to plugin as arglist or NULL.
- */
-struct arglist *
-plug_create_from_nvti_and_prefs (const nvti_t * nvti)
-{
-  struct arglist *ret;
-  int i;
-
-  if (!nvti)
-    return NULL;
-
-  ret = g_malloc0 (sizeof (struct arglist));
-
-  for (i = 0; i < nvti_pref_len (nvti); i++)
-    {
-      const nvtpref_t *np = nvti_pref (nvti, i);
-      _add_plugin_preference (nvti_name (nvti), nvtpref_name (np),
-                              nvtpref_type (np), nvtpref_default (np));
-    }
-
-  return ret;
-}
-
-void
-host_add_port_proto (struct arglist *args, int portnum, int state, char *proto)
+host_add_port_proto (struct arglist *args, int portnum, char *proto)
 {
   char port_s[255];
-  snprintf (port_s, sizeof (port_s), "Ports/%s/%d", proto, portnum);    /* RATS: ignore */
+  snprintf (port_s, sizeof (port_s), "Ports/%s/%d", proto, portnum);
   plug_set_key (args, port_s, ARG_INT, (void *) 1);
 }
 
@@ -258,9 +189,9 @@ host_get_port_state_udp (struct arglist *plugdata, int portnum)
 const char *
 plug_get_hostname (struct arglist *desc)
 {
-  struct arglist *hinfos = arg_get_value (desc, "HOSTNAME");
-  if (hinfos)
-    return ((char *) arg_get_value (hinfos, "NAME"));
+  struct host_info *hinfo = arg_get_value (desc, "HOSTNAME");
+  if (hinfo)
+    return hinfo->name;
   else
     return (NULL);
 }
@@ -268,7 +199,7 @@ plug_get_hostname (struct arglist *desc)
 char *
 plug_get_host_fqdn (struct arglist *desc)
 {
-  struct arglist *hinfos = arg_get_value (desc, "HOSTNAME");
+  struct host_info *hinfos = arg_get_value (desc, "HOSTNAME");
   if (hinfos)
     {
       int type;
@@ -276,7 +207,7 @@ plug_get_host_fqdn (struct arglist *desc)
       if (vhosts)
         return vhosts;
       else
-        return g_strdup (arg_get_value (hinfos, "FQDN"));
+        return g_strdup (hinfos->fqdn);
     }
   else
     return (NULL);
@@ -286,11 +217,10 @@ plug_get_host_fqdn (struct arglist *desc)
 struct in6_addr *
 plug_get_host_ip (struct arglist *desc)
 {
-  struct arglist *hinfos = arg_get_value (desc, "HOSTNAME");
+  struct host_info *hinfos = arg_get_value (desc, "HOSTNAME");
   if (hinfos)
-    return ((struct in6_addr *) arg_get_value (hinfos, "IP"));
-  else
-    return NULL;
+    return hinfos->ip;
+  return NULL;
 }
 
 char *
@@ -459,7 +389,7 @@ proto_post_wrapped (const char *oid, struct arglist *desc, int port, const char
     }
   else
     {
-      snprintf (idbuffer, sizeof (idbuffer), "<|> %s ", oid);   /* RATS: ignore */
+      snprintf (idbuffer, sizeof (idbuffer), "<|> %s ", oid);
     }
   if (port > 0)
     {
@@ -475,7 +405,7 @@ proto_post_wrapped (const char *oid, struct arglist *desc, int port, const char
               idbuffer);
 
   mark_post (oid, desc, what, action);
-  soc = arg_get_value_int (desc, "SOCKET");
+  soc = arg_get_value_int (arg_get_value (desc, "globals"), "global_socket");
   /* Convert to UTF-8 before sending to Manager. */
   data = g_convert (buffer, -1, "UTF-8", "ISO_8859-1", NULL, &length, NULL);
   internal_send (soc, data, INTERNAL_COMM_MSG_TYPE_DATA);
@@ -550,7 +480,6 @@ add_plugin_preference (struct arglist *desc, const char *name, const char *type,
 char *
 get_plugin_preference (const char *oid, const char *name)
 {
-  int len;
   struct arglist *prefs;
   char *plug_name, *cname;
   nvti_t * nvti;
@@ -565,14 +494,7 @@ get_plugin_preference (const char *oid, const char *name)
   plug_name = nvti_name (nvti);
   cname = g_strdup (name);
 
-  len = strlen (cname);
-
-  while (cname[len - 1] == ' ')
-    {
-      cname[len - 1] = '\0';
-      len--;
-    }
-
+  g_strchomp (cname);
   while (prefs->next)
     {
       char *a, *b;
@@ -700,7 +622,7 @@ get_plugin_preference_file_content (struct arglist *desc,
  * @return Size of the file identified by \ref identifier, -1 if not found or
  *         setup broken.
  */
-const long
+long
 get_plugin_preference_file_size (struct arglist *desc, const char *identifier)
 {
   struct arglist *globals = arg_get_value (desc, "globals");
@@ -769,7 +691,7 @@ plug_replace_key (struct arglist *args, char *name, int type, void *value)
 void
 scanner_add_port (struct arglist *args, int port, char *proto)
 {
-  host_add_port_proto (args, port, 1, proto);
+  host_add_port_proto (args, port, proto);
 }
 
 
@@ -787,7 +709,7 @@ plug_get_kb (struct arglist *args)
 static int _plug_get_key_son = 0;
 
 static void
-plug_get_key_sighand_term (int sig)
+plug_get_key_sighand_term ()
 {
   int son = _plug_get_key_son;
 
@@ -800,7 +722,7 @@ plug_get_key_sighand_term (int sig)
 }
 
 static void
-plug_get_key_sigchld (int sig)
+plug_get_key_sigchld ()
 {
   int status;
 
@@ -819,13 +741,13 @@ sig_n (int signo, void (*fnc) (int))
 }
 
 static void
-sig_term (void (*fcn) (int))
+sig_term (void (*fcn) ())
 {
   sig_n (SIGTERM, fcn);
 }
 
 static void
-sig_chld (void (*fcn) (int))
+sig_chld (void (*fcn) ())
 {
   sig_n (SIGCHLD, fcn);
 }
@@ -884,15 +806,15 @@ plug_get_key (struct arglist *args, char *name, int *type)
           void *ret;
 
           kb_lnk_reset (kb);
+          nvticache_reset ();
           close (sockpair[0]);
           globals = arg_get_value (args, "globals");
           old = arg_get_value_int (globals, "global_socket");
           if (old > 0)
             close (old);
           arg_set_value (globals, "global_socket", GSIZE_TO_POINTER (sockpair[1]));
-          arg_set_value (args, "SOCKET", GSIZE_TO_POINTER (sockpair[1]));
 
-          srand48 (getpid () + getppid () + time (NULL)); /* RATS: ignore */
+          srand48 (getpid () + getppid () + time (NULL));
 
           if (res->type == KB_TYPE_INT)
             {
@@ -1018,7 +940,7 @@ plug_get_host_open_port (struct arglist *desc)
 
       kb_item_free (k);
       if (num_candidates != 0)
-        return candidates[lrand48 () % num_candidates]; /* RATS: ignore */
+        return candidates[lrand48 () % num_candidates];
       else if (open21)
         return 21;
       else if (open80)
@@ -1043,7 +965,7 @@ plug_set_port_transport (struct arglist *args, int port, int tr)
 {
   char s[256];
 
-  snprintf (s, sizeof (s), "Transports/TCP/%d", port);  /* RATS: ignore */
+  snprintf (s, sizeof (s), "Transports/TCP/%d", port);
   plug_set_key (args, s, ARG_INT, GSIZE_TO_POINTER (tr));
 }
 
@@ -1058,7 +980,7 @@ plug_get_port_transport (struct arglist *args, int port)
   char s[256];
   int trp;
 
-  snprintf (s, sizeof (s), "Transports/TCP/%d", port);  /* RATS: ignore */
+  snprintf (s, sizeof (s), "Transports/TCP/%d", port);
   trp = kb_item_get_int (plug_get_kb (args), s);
   if (trp >= 0)
     return trp;
@@ -1071,7 +993,7 @@ static void
 plug_set_ssl_item (struct arglist *args, char *item, char *itemfname)
 {
   char s[256];
-  snprintf (s, sizeof (s), "SSL/%s", item);     /* RATS: ignore */
+  snprintf (s, sizeof (s), "SSL/%s", item);
   plug_set_key (args, s, ARG_STRING, itemfname);
 }
 
@@ -1134,7 +1056,7 @@ find_in_path (char *name, int safe)
         /* path too long: cannot be reached */
         continue;
 
-      snprintf (p2, MAXPATHLEN, "/%s", name);   /* RATS: ignore */
+      snprintf (p2, MAXPATHLEN, "/%s", name);
       if (access (cmd, X_OK) == 0)
         {
           struct stat st;
