@@ -13,12 +13,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
-#include "nasl_regex.h"
-
 #include "nasl.h"
 #include "nasl_tree.h"
 #include "nasl_global_ctxt.h"
@@ -26,10 +24,8 @@
 #include "nasl_var.h"
 #include "nasl_lex_ctxt.h"
 #include "exec.h"
-#include "preparse.h"
 
 #include "nasl_debug.h"
-#include "strutils.h"
 #include "nasl_init.h"
 
 #ifndef NASL_DEBUG
