@@ -26,17 +26,20 @@
 #include <stdlib.h>             /* for exit */
 #include <unistd.h>             /* for geteuid */
 #include <libssh/libssh.h>      /* for ssh_version */
+#include <gnutls/gnutls.h>      /* for gnutls_check_version */
+#include <sys/wait.h>
 
-#include "kb.h"                 /* for kb_new */
-#include "network.h"
+#include "../misc/network.h"
 
 #include "nasl.h"
 #include "nasl_lex_ctxt.h"
 #include "exec.h"
 #include "../base/gpgme_util.h" /* for gpgme_check_version */
-#include <../base/openvas_hosts.h> /* for openvas_hosts_* and openvas_host_* */
-#include <../base/nvti.h>
-#include <../misc/prefs.h> /* for prefs_get */
+#include "../base/kb.h"                 /* for kb_new */
+#include "../base/openvas_hosts.h" /* for openvas_hosts_* and openvas_host_* */
+#include "../base/nvti.h"
+#include "../misc/prefs.h" /* for prefs_get */
+#include "../misc/nvt_categories.h"
 
 #include <glib.h>
 
@@ -50,22 +53,8 @@ extern int execute_instruction (struct arglist *, char *);
 void exit_nasl (struct arglist *, int);
 
 
-int safe_checks_only = 0;
-
-static struct arglist *
-init_hostinfos (char *hostname, struct in6_addr *ip)
-{
-  struct arglist *hostinfos;
-
-  hostinfos = g_malloc0 (sizeof (struct arglist));
-  arg_add_value (hostinfos, "FQDN", ARG_STRING, hostname);
-  arg_add_value (hostinfos, "NAME", ARG_STRING, hostname);
-  arg_add_value (hostinfos, "IP", ARG_PTR, ip);
-  return (hostinfos);
-}
-
 void
-sighandler (int s)
+sighandler ()
 {
   exit (0);
 }
@@ -79,29 +68,23 @@ my_gnutls_log_func (int level, const char *text)
 }
 
 struct arglist *
-init (char *hostname, struct in6_addr ip, kb_t kb)
+init (char *hostname, struct in6_addr *ip, char *fqdn, kb_t kb)
 {
   struct arglist *script_infos = g_malloc0 (sizeof (struct arglist));
-  struct in6_addr *pip = g_malloc0 (sizeof (*pip));
-
-  memcpy (pip, &ip, sizeof (struct in6_addr));
 
   arg_add_value (script_infos, "standalone", ARG_INT, (void *) 1);
   prefs_set ("checks_read_timeout", "5");
   arg_add_value (script_infos, "key", ARG_PTR, kb);
 
-  if (safe_checks_only != 0)
-    prefs_set ("safe_checks", "yes");
-
-  arg_add_value (script_infos, "HOSTNAME", ARG_ARGLIST,
-                 init_hostinfos (hostname, pip));
+  arg_add_value (script_infos, "HOSTNAME", ARG_PTR,
+                 host_info_init (hostname, ip, NULL, fqdn));
 
   return script_infos;
 }
 
 extern FILE *nasl_trace_fp;
 
-static int
+static nvti_t *
 parse_script_infos (const char *file, struct arglist *script_infos)
 {
   nvti_t *nvti;
@@ -114,17 +97,33 @@ parse_script_infos (const char *file, struct arglist *script_infos)
   if (exec_nasl_script (script_infos, file, NULL, mode) < 0)
     {
       printf ("%s could not be loaded\n", file);
-      return 1;
+      return NULL;
     }
   arg_del_value (script_infos, "NVTI");
 
   arg_del_value (script_infos, "OID");
   oid = g_strdup (nvti_oid (nvti));
-  nvti_free (nvti);
   if (oid)
     arg_add_value (script_infos, "OID", ARG_STRING, oid);
 
-  return 0;
+  return nvti;
+}
+
+
+/**
+ * @brief Checks that an NVT category is safe.
+ *
+ * @param category  Category to check.
+ *
+ * @return 0 if category is unsafe, 1 otherwise.
+ */
+static int
+nvti_category_is_safe (int category)
+{
+  if (category == ACT_DESTRUCTIVE_ATTACK || category == ACT_KILL_HOST
+      || category == ACT_FLOOD || category == ACT_DENIAL)
+    return 0;
+  return 1;
 }
 
 /**
@@ -140,9 +139,7 @@ main (int argc, char **argv)
   openvas_host_t *host;
   static gchar *target = NULL;
   gchar *default_target = "127.0.0.1";
-  int start, n;
-  int mode = 0;
-  int err = 0;
+  int mode = 0, n = 0, err = 0;
   extern int global_nasl_debug;
 
   static gboolean display_version = FALSE;
@@ -158,6 +155,7 @@ main (int argc, char **argv)
   static gboolean authenticated_mode = FALSE;
   static gchar *include_dir = NULL;
   static gchar **nasl_filenames = NULL;
+  static gchar **kb_values = NULL;
   static int debug_tls = 0;
   GError *error = NULL;
   GOptionContext *option_context;
@@ -179,7 +177,7 @@ main (int argc, char **argv)
     {"trace", 'T', 0, G_OPTION_ARG_FILENAME, &trace_file,
      "Log actions to <file> (or '-' for stderr)", "<file>"},
     {"config-file", 'c', 0, G_OPTION_ARG_FILENAME, &config_file,
-     "Configuration file", "<filenmae>"},
+     "Configuration file", "<filename>"},
     {"source-iface", 'e', 0, G_OPTION_ARG_STRING, &source_iface,
      "Source network interface for established connections.",
      "<iface_name>"},
@@ -192,6 +190,8 @@ main (int argc, char **argv)
      "Search for includes in <dir>", "<dir>"},
     {"debug-tls", 0, 0, G_OPTION_ARG_INT, &debug_tls,
      "Enable TLS debugging at <level>", "<level>"},
+    {"kb", 'k', 0, G_OPTION_ARG_STRING_ARRAY, &kb_values,
+     "Set KB key to vaue. Can be used multiple times", "<key=value>"},
     {G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &nasl_filenames,
      "Absolute path to one or more nasl scripts", "NASL_FILE..."},
     {NULL}
@@ -253,7 +253,7 @@ main (int argc, char **argv)
         }
     }
   if (with_safe_checks)
-    safe_checks_only++;
+    prefs_set ("safe_checks", "yes");
 
   openvas_SSL_init ();
   if (!nasl_filenames)
@@ -288,8 +288,6 @@ main (int argc, char **argv)
   if (!target)
     target = g_strdup (default_target);
 
-  start = 0;
-
   hosts = openvas_hosts_new (target);
   g_free (target);
 
@@ -304,7 +302,7 @@ main (int argc, char **argv)
   while ((host = openvas_hosts_next (hosts)))
     {
       struct in6_addr ip6;
-      char *hostname;
+      char *hostname, *fqdn;
       kb_t kb;
       int rc;
 
@@ -321,16 +319,70 @@ main (int argc, char **argv)
       if (rc)
         exit (1);
 
-      script_infos = init (hostname, ip6, kb);
-      n = start;
+      fqdn = openvas_host_reverse_lookup (host);
+      script_infos = init (hostname, &ip6, fqdn ?: hostname, kb);
+      g_free (fqdn);
       while (nasl_filenames[n])
         {
-          if (both_modes && parse_script_infos (nasl_filenames[n],
-                                                script_infos))
-            err++;
-          else if (exec_nasl_script (script_infos, nasl_filenames[n],
-                                     arg_get_value (script_infos, "OID"), mode) < 0)
-            err++;
+          pid_t pid;
+
+          if (both_modes || with_safe_checks)
+            {
+              nvti_t *nvti = parse_script_infos (nasl_filenames[n],
+                                                 script_infos);
+              if (!nvti)
+                {
+                  err++;
+                  n++;
+                  continue;
+                }
+              else if (with_safe_checks
+                       && !nvti_category_is_safe (nvti_category (nvti)))
+                {
+                  printf ("%s isn't safe\n", nasl_filenames[n]);
+                  nvti_free (nvti);
+                  err++;
+                  n++;
+                  continue;
+                }
+              nvti_free (nvti);
+            }
+          if (kb_values)
+            {
+              while (*kb_values)
+                {
+                  gchar **splits = g_strsplit (*kb_values, "=", -1);
+                  if (splits[2] || !splits[1])
+                    {
+                      fprintf (stderr, "Erroneous --kb entry %s\n", *kb_values);
+                      exit (1);
+                    }
+                  kb_item_add_str (kb, splits[0], splits[1]);
+                  kb_values++;
+                  g_strfreev (splits);
+                }
+            }
+
+          if ((pid = fork ()) == 0)
+            {
+              if (exec_nasl_script (script_infos, nasl_filenames[n],
+                                    arg_get_value (script_infos, "OID"), mode) < 0)
+                exit (1);
+              else
+                exit (0);
+            }
+          else if (pid < 0)
+            {
+              fprintf (stderr, "fork(): %s\n", strerror (errno));
+              exit (1);
+            }
+          else
+            {
+              int status;
+              waitpid (pid, &status, 0);
+              if (status)
+                err++;
+            }
           n++;
         }
       kb_delete (kb);
