@@ -33,8 +33,8 @@
 
 #include "../misc/arglists.h"   /* for struct arglist */
 #include "../misc/network.h"    /* for get_encaps_through */
-#include "nvt_categories.h"     /* for ACT_SCANNER */
 #include "../misc/plugutils.h"  /* for OPENVAS_ENCAPS_IP */
+#include "../base/nvticache.h"
 
 #include "nasl_lex_ctxt.h"
 
@@ -52,14 +52,6 @@
 
 #define NUM_CHILDREN		"Number of connections done in parallel : "
 
-/* Plugin preference types (influence gui in client) */
-#define PREF_CHECKBOX "checkbox"
-#define PREF_ENTRY "entry"
-#define PREF_RADIO "radio"
-#define PREF_PASSWORD "password"
-#define PREF_FILE "file"
-
-
 const char *oid;
 
 static void
@@ -441,10 +433,10 @@ mark_cvslockserver (struct arglist *desc, int port, char *buffer, int trp)
 }
 
 void
-mark_rsyncd (struct arglist *desc, int port, char *buffer, int trp)
+mark_rsync (struct arglist *desc, int port, char *buffer, int trp)
 {
-  register_service (desc, port, "rsyncd");
-  post_log (oid, desc, port, "An rsync server is running on this port");
+  register_service (desc, port, "rsync");
+  post_log (oid, desc, port, "A rsync server is running on this port");
 }
 
 
@@ -1530,8 +1522,8 @@ plugin_do_run (struct arglist *desc, struct arglist *h, int test_ssl)
   struct timeval tv;
   char k[32], *http_get;
 #ifdef DEBUG
-  struct arglist *hostinfos = arg_get_value (desc, "HOSTNAME");
-  struct in_addr *p_ip = arg_get_value (hostinfos, "IP");
+  struct host_info *hostinfo = arg_get_value (desc, "HOSTNAME");
+  struct in_addr *p_ip = hostinfo->ip;
 #endif
 
   host_fqdn = plug_get_host_fqdn (desc);
@@ -1846,7 +1838,7 @@ plugin_do_run (struct arglist *desc, struct arglist *h, int test_ssl)
                   banner[len] = '\0';
 
                   for (i = 0; i < len; i++)
-                    buffer[i] = tolower (buffer[i]);
+                    buffer[i] = ( buffer[i] == '\0' ) ? 'x' : tolower (buffer[i]);
 
                   line = g_strdup (buffer);
 
@@ -2004,10 +1996,8 @@ plugin_do_run (struct arglist *desc, struct arglist *h, int test_ssl)
                   else if (strncmp (line, "421", 3) == 0
                            && strstr (line, "smtp ") != NULL)
                     mark_smtp_server (desc, port, origline, trp);
-                  else if (line[0] != '\0'
-                           && (strncmp (line + 1, "host '", 6) == 0)
-                           && strstr (line, "mysql") != NULL)
-                    mark_mysql (desc, port, origline);
+                  else if ( line[0] != '\0' && ( ( strncmp (buffer + 1,"host '", 6) == 0) || ( strstr (buffer, "mysql") != NULL || strstr (buffer,"mariadb") != NULL ) ) )
+                     mark_mysql (desc, port, origline);
                   else if (!strncmp (line, "efatal", 6)
                            || !strncmp (line, "einvalid packet length",
                                         strlen ("einvalid packet length")))
@@ -2020,7 +2010,7 @@ plugin_do_run (struct arglist *desc, struct arglist *h, int test_ssl)
                   else if (!strncmp (line, "cvslock ", 8))
                     mark_cvslockserver (desc, port, origline, trp);
                   else if (!strncmp (line, "@rsyncd", 7))
-                    mark_rsyncd (desc, port, origline, trp);
+                    mark_rsync (desc, port, origline, trp);
                   else if ((len == 4) && may_be_time ((time_t *) banner))
                     mark_time_server (desc, port, banner, trp);
                   else if (strstr (buffer, "rmserver")
@@ -2673,12 +2663,12 @@ plugin_run_find_service (lex_ctxt * lexic)
               int soc;
 
               kb_lnk_reset (kb);
+              nvticache_reset ();
               soc = arg_get_value_int (globals, "global_socket");
               close (sons_pipe[i][1]);
               close (soc);
               soc = sons_pipe[i][0];
               arg_set_value (globals, "global_socket", GSIZE_TO_POINTER (soc));
-              arg_set_value (desc, "SOCKET", GSIZE_TO_POINTER (soc));
               signal (SIGTERM, _exit);
               plugin_do_run (desc, sons_args[i], test_ssl);
               exit (0);
