@@ -1,5 +1,5 @@
 /* OpenVAS
-* $Id: nasl_builtin_nmap.c 24345 2016-02-09 21:43:29Z kroosec $
+* $Id: nasl_builtin_nmap.c 24344 2016-02-09 21:42:00Z kroosec $
 * Description: Advanced wrapper from nmap
 *
 * Authors:
@@ -63,9 +63,9 @@
 #include "../misc/arglists.h"
 #include "../misc/plugutils.h"
 #include "../misc/popen.h"
-#include "../misc/kb.h"
 #include "../misc/openvas_logging.h"
 #include "../misc/prefs.h"  /* for prefs_get */
+#include "../base/kb.h"
 
 #include "nasl_lex_ctxt.h"
 
@@ -1144,7 +1144,7 @@ nmap_run_and_parse (nmap_t * nmap)
 
               /* display the problematic chunk */
               chunk[len] = '\0';
-              dbg ("Error occured while parsing: %s\n", chunk);
+              dbg ("Error occurred while parsing: %s\n", chunk);
 
               ret = -1;
             }
@@ -1366,8 +1366,6 @@ xml_start_element (GMarkupParseContext * context, const gchar * element_name,
  *
  * @param[in] context  The XML parser.
  * @param[in] element_name  The name of the current tag.
- * @param[in] attribute_names  NULL terminated list of attributes names.
- * @param[in] attribute_values  NULL terminated list of attributes values.
  * @param[in] user_data  A pointer to the current nmap_t structure.
  * @param[in] error  Return location of a GError.
  */
