@@ -38,12 +38,11 @@
 
 #include "../misc/arglists.h" /* for struct arglist */
 #include "../misc/bpf_share.h" /* for bpf_open_live */
-#include "nvt_categories.h" /* for ACT_SCANNER */
 #include "../misc/pcap_openvas.h" /* for get_datalink_size */
 #include "../misc/plugutils.h" /* for scanner_add_port */
 #include "../misc/openvas_logging.h"
 #include "../misc/prefs.h"          /* for prefs_get */
-#include "network.h"    /* for getpts */
+#include "../misc/network.h"    /* for getpts */
 
 #include "nasl_lex_ctxt.h"
 
@@ -233,7 +232,7 @@ openbpf (struct in_addr dst, struct in_addr * src, int magic)
 
 	iface = routethrough (&dst, src);
 #ifdef DEBUG
-        printf ("Source adress found via routethrough: %s\n", inet_ntoa (*src));
+        printf ("Source address found via routethrough: %s\n", inet_ntoa (*src));
 #endif
         snprintf (filter, sizeof (filter), "tcp and src host %s and dst port %d", inet_ntoa (dst), magic);
 #ifdef DEBUG
@@ -725,7 +724,7 @@ scan (struct arglist * env, char* hostname, char* portrange,
   for (i = 0; i < num ; i += 2)
     {
 #ifdef DEBUG
-      printf ("====> Sending packet to (at least) %d\n", ports[i]);
+      printf ("====> Sending packet to (at least) %u\n", ports[i]);
 #endif
       if (family == AF_INET)
         packets = sendpacket (soc, bpf, skip, dst, src, ports[i], magic,
@@ -736,7 +735,7 @@ scan (struct arglist * env, char* hostname, char* portrange,
       if (i + 1 < num)
         {
 #ifdef DEBUG
-          printf ("=====>> Sniffing %d\n", ports[i+1]);
+          printf ("=====>> Sniffing %u\n", ports[i+1]);
 #endif
           if (family == AF_INET)
             packets = sendpacket (soc, bpf, skip, dst, src, ports[i + 1],
@@ -803,7 +802,7 @@ plugin_run_synscan (lex_ctxt * lexic)
   if (islocalhost (dst))
     return NULL;
 
-    rtt = htonl (1 << 28);
+  rtt = htonl (1 << 28);
 
 #ifdef DEBUG
   printf ("RTT = 0x%.8x\n", ntohl (rtt));
@@ -811,9 +810,9 @@ plugin_run_synscan (lex_ctxt * lexic)
   printf ("That's %ld seconds and %ld usecs\n", tv.tv_sec, tv.tv_usec);
 #endif
 
-  struct arglist *hostinfos = arg_get_value (env, "HOSTNAME");
-  char           *hostname  = arg_get_value (hostinfos, "NAME");
-  const char     *range = prefs_get ("port_range");
+  struct host_info *hostinfo = arg_get_value (env, "HOSTNAME");
+  char *hostname = hostinfo->name;
+  const char *range = prefs_get ("port_range");
   scan (env, hostname, (char *)range, dst6, rtt);
   plug_set_key (env, "Host/scanned", ARG_INT, (void *) 1);
   plug_set_key (env, "Host/scanners/synscan", ARG_INT, (void*)1);
