@@ -45,7 +45,7 @@
 #include <gnutls/gnutls.h>
 #include <gnutls/x509.h>
 
-#include "openvas_logging.h"
+#include "../misc/openvas_logging.h"
 #include "nasl_tree.h"
 #include "nasl_global_ctxt.h"
 #include "nasl_func.h"
@@ -466,9 +466,8 @@ build_hostname_list (ksba_cert_t cert)
   value = parse_dn_for_CN (name);
   ksba_free (name);
 
-  /* Add the CN to the array but only if it looks like a hostname.  We
-     assume a hostname if at least one dot is in the name.  */
-  if (value && strchr (value, '.'))
+  /* Add the CN to the array even if it doesn't look like a hostname. */
+  if (value)
     {
       memset (&v, 0, sizeof v);
       v.var_type = VAR2_DATA;
@@ -585,6 +584,14 @@ get_oid_name (const char *oid)
     return "id-ecMQV";
   else if (!strcmp ("1.2.840.113549.1.1.10", oid))
     return "id-RSASSA-PSS";
+  else if (!strcmp ("1.2.840.113549.1.1.11", oid))
+    return "sha256WithRSAEncryption";
+  else if (!strcmp ("1.2.840.113549.1.1.12", oid))
+    return "sha384WithRSAEncryption";
+  else if (!strcmp ("1.2.840.113549.1.1.13", oid))
+    return "sha512WithRSAEncryption";
+  else if (!strcmp ("1.2.840.113549.1.1.14", oid))
+    return "sha224WithRSAEncryption";
   else if (!strcmp ("1.2.840.113549.1.1.8", oid))
     return "id-mgf1";
   else if (!strcmp ("1.2.840.113549.2.2", oid))
@@ -890,6 +897,54 @@ nasl_cert_query (lex_ctxt *lexic)
           retc->size = strlen (name);
         }
     }
+  else if (!strcmp (command, "modulus"))
+    {
+      gnutls_datum_t datum, m, e;
+      gnutls_x509_crt_t cert = NULL;
+
+      datum.data = (void *) ksba_cert_get_image (obj->cert, (size_t *)
+                                                 &datum.size);
+      if (!datum.data)
+        return NULL;
+      if (gnutls_x509_crt_init (&cert) != GNUTLS_E_SUCCESS)
+        return NULL;
+      if (gnutls_x509_crt_import (cert, &datum, GNUTLS_X509_FMT_DER)
+          != GNUTLS_E_SUCCESS)
+        return NULL;
+      if (gnutls_x509_crt_get_pk_rsa_raw (cert, &m, &e) != GNUTLS_E_SUCCESS)
+        return NULL;
+
+      retc = alloc_typed_cell (CONST_DATA);
+      retc->size = m.size;
+      retc->x.str_val = g_memdup (m.data, m.size);
+      gnutls_free (m.data);
+      gnutls_free (e.data);
+      gnutls_x509_crt_deinit (cert);
+    }
+  else if (!strcmp (command, "exponent"))
+    {
+      gnutls_datum_t datum, m, e;
+      gnutls_x509_crt_t cert = NULL;
+
+      datum.data = (void *) ksba_cert_get_image (obj->cert, (size_t *)
+                                                 &datum.size);
+      if (!datum.data)
+        return NULL;
+      if (gnutls_x509_crt_init (&cert) != GNUTLS_E_SUCCESS)
+        return NULL;
+      if (gnutls_x509_crt_import (cert, &datum, GNUTLS_X509_FMT_DER)
+          != GNUTLS_E_SUCCESS)
+        return NULL;
+      if (gnutls_x509_crt_get_pk_rsa_raw (cert, &m, &e) != GNUTLS_E_SUCCESS)
+        return NULL;
+
+      retc = alloc_typed_cell (CONST_DATA);
+      retc->size = e.size;
+      retc->x.str_val = g_memdup (e.data, e.size);
+      gnutls_free (m.data);
+      gnutls_free (e.data);
+      gnutls_x509_crt_deinit (cert);
+    }
   else if (!strcmp (command, "key-size"))
     {
       gnutls_datum_t datum;
