@@ -36,6 +36,7 @@
 #include "hmacmd5.h"
 #include "smb_crypt.h"
 #include "nasl_debug.h"
+#include "../misc/openvas_logging.h"
 
 #include <ctype.h>
 #include <stdlib.h>
@@ -146,8 +147,51 @@ nasl_ripemd160 (lex_ctxt * lexic)
   return nasl_hash (lexic, GCRY_MD_RMD160);
 }
 
+static tree_cell *
+nasl_cipher (int algorithm, void *data, size_t dlen, void *key, size_t klen)
+{
+  gcry_cipher_hd_t hd;
+  gcry_error_t error;
+  tree_cell *retc;
+  char *result;
 
+  if ((error = gcry_cipher_open (&hd, algorithm, GCRY_CIPHER_MODE_ECB, 0)))
+    {
+      log_legacy_write ("gcry_cipher_open: %s", gcry_strerror (error));
+      return NULL;
+    }
+  if ((error = gcry_cipher_setkey (hd, key, klen)))
+    {
+      log_legacy_write ("gcry_cipher_setkey: %s", gcry_strerror (error));
+      return NULL;
+    }
+  result = g_malloc0 (dlen);
+  if ((error = gcry_cipher_encrypt (hd, result, dlen, data, dlen)))
+    {
+      log_legacy_write ("gcry_cipher_encrypt: %s", gcry_strerror (error));
+      return NULL;
+    }
+  gcry_cipher_close (hd);
 
+  retc = alloc_tree_cell (0, NULL);
+  retc->type = CONST_DATA;
+  retc->x.str_val = result;
+  retc->size = dlen;
+  return retc;
+}
+
+tree_cell *
+nasl_cipher_des (lex_ctxt *lexic)
+{
+  char *data, *key;
+  size_t dlen, klen;
+
+  data = get_str_var_by_num (lexic, 0);
+  dlen = get_var_size_by_num (lexic, 0);
+  key = get_str_var_by_num (lexic, 1);
+  klen = get_var_size_by_num (lexic, 1);
+  return nasl_cipher (GCRY_CIPHER_DES, data, dlen, key, klen);
+}
 
 /*-------------------[  HMAC ]-------------------------------------*/
 
@@ -182,6 +226,12 @@ nasl_hmac_sha1 (lex_ctxt * lexic)
   return nasl_hmac (lexic, GCRY_MD_SHA1);
 }
 
+tree_cell *
+nasl_hmac_sha384 (lex_ctxt * lexic)
+{
+  return nasl_hmac (lexic, GCRY_MD_SHA384);
+}
+
 tree_cell *
 nasl_hmac_ripemd160 (lex_ctxt * lexic)
 {
@@ -216,7 +266,7 @@ nasl_get_sign (lex_ctxt * lexic)
 }
 
 static void *
-hmac_sha256 (void *key, int keylen, void *buf, int buflen)
+hmac_sha256 (const void *key, int keylen, const void *buf, int buflen)
 {
   void *signature = g_malloc0 (32);
   gsize signlen = 32;
@@ -229,24 +279,59 @@ hmac_sha256 (void *key, int keylen, void *buf, int buflen)
   return signature;
 }
 
+static void *
+hmac_sha384 (const void *key, int keylen, const void *buf, int buflen)
+{
+  gcry_md_hd_t hd;
+  gcry_error_t err;
+  void *ret;
+
+  if (!buf || buflen <= 0)
+    return NULL;
+
+  err = gcry_md_open (&hd, GCRY_MD_SHA384, key ? GCRY_MD_FLAG_HMAC : 0);
+  if (err)
+    {
+      log_legacy_write ("nasl_gcrypt_hash(): gcry_md_open failed: %s/%s\n",
+                        gcry_strsource (err), gcry_strerror (err));
+      return NULL;
+    }
+
+  if (key)
+    {
+      err = gcry_md_setkey (hd, key, keylen);
+      if (err)
+        {
+          log_legacy_write ("nasl_gcrypt_hash(): gcry_md_setkey failed: %s/%s\n",
+                            gcry_strsource (err), gcry_strerror (err));
+          return NULL;
+        }
+    }
+
+  gcry_md_write (hd, buf, buflen);
+  ret = g_memdup (gcry_md_read (hd, 0), 48);
+  gcry_md_close (hd);
+  return ret;
+}
+
 tree_cell *
 nasl_hmac_sha256 (lex_ctxt * lexic)
 {
-  void *key, *buf, *signature;
-  int keylen, buflen;
+  void *key, *data, *signature;
+  int keylen, datalen;
   tree_cell *retc;
 
   key = get_str_var_by_name (lexic, "key");
-  buf = get_str_var_by_name (lexic, "buf");
-  keylen = get_int_var_by_name (lexic, "keylen", -1);
-  buflen = get_int_var_by_name (lexic, "buflen", -1);
-  if (!key || !buf || keylen <= 0 || buflen <= 0)
+  data = get_str_var_by_name (lexic, "data");
+  datalen = get_local_var_size_by_name (lexic, "data");
+  keylen = get_local_var_size_by_name (lexic, "key");
+  if (!key || !data || keylen <= 0 || datalen <= 0)
     {
       nasl_perror (lexic,
-                   "Syntax : hmac_sha256(buf:<b>, buflen:<bl>, key:<k>, keylen:<kl>)\n");
+                   "Syntax : hmac_sha256(data:<b>, key:<k>)\n");
       return NULL;
     }
-  signature = hmac_sha256 (key, keylen, buf, buflen);
+  signature = hmac_sha256 (key, keylen, data, datalen);
 
   retc = alloc_tree_cell (0, NULL);
   retc->type = CONST_DATA;
@@ -255,6 +340,124 @@ nasl_hmac_sha256 (lex_ctxt * lexic)
   return retc;
 }
 
+/* @brief PRF function from RFC 2246 chapter 5.
+ *
+ * @param hmac   0 for SHA256, 1 for SHA384.
+ *
+ * */
+static void *
+tls_prf (const void *secret, size_t secret_len, const void *seed,
+         size_t seed_len, const void *label, size_t outlen, int hmac)
+{
+  char *result = NULL;
+  size_t pos = 0, lslen, hmac_size;
+  void *Ai;
+  void *lseed;
+  void *(* hmac_func) (const void *, int, const void *, int);
+
+  if (hmac == 0)
+    {
+      hmac_size = 32;
+      hmac_func = hmac_sha256;
+    }
+  else
+    {
+      hmac_size = 48;
+      hmac_func = hmac_sha384;
+    }
+
+  /*
+   * A0 = seed
+   * Ai = HMAC(secret, A(i - 1))
+   * lseed = label + seed
+   */
+  Ai = hmac_func (secret, secret_len, seed, seed_len);
+  lslen = strlen (label) + seed_len;
+  lseed = g_malloc0 (lslen);
+  memcpy (lseed, label, strlen (label));
+  memcpy (lseed + strlen (label), seed, seed_len);
+
+  result = g_malloc0 (outlen);
+  while (pos < outlen)
+    {
+      void *tmp, *tmp2;
+      size_t clen;
+
+      /* HMAC_hash(secret, Ai + lseed) */
+      tmp = g_malloc0 (hmac_size + lslen);
+      memcpy (tmp, Ai, hmac_size);
+      memcpy (tmp + hmac_size, lseed, lslen);
+      tmp2 = hmac_func (secret, secret_len, tmp, hmac_size + lslen);
+      g_free (tmp);
+      /* concat to result */
+      clen = outlen - pos;
+      if (clen > hmac_size)
+        clen = hmac_size;
+      memcpy (result + pos, tmp2, clen);
+      pos += clen;
+      g_free (tmp2);
+
+      /* A(i+1) */
+      tmp = hmac_func (secret, secret_len, Ai, hmac_size);
+      g_free (Ai);
+      Ai = tmp;
+    }
+
+  g_free (Ai);
+  g_free (lseed);
+  return result;
+}
+
+static tree_cell *
+nasl_prf (lex_ctxt * lexic, int hmac)
+{
+  void *secret, *seed, *label, *result;
+  int secret_len, seed_len, label_len, outlen;
+  tree_cell *retc;
+
+  secret = get_str_var_by_name (lexic, "secret");
+  seed = get_str_var_by_name (lexic, "seed");
+  label = get_str_var_by_name (lexic, "label");
+  outlen = get_int_var_by_name (lexic, "outlen", -1);
+  seed_len = get_local_var_size_by_name (lexic, "seed");
+  secret_len = get_local_var_size_by_name (lexic, "secret");
+  label_len = get_local_var_size_by_name (lexic, "label");
+  if (!secret || !seed || secret_len <= 0 || seed_len <= 0 || !label
+      || label_len <= 0 || outlen <= 0)
+    {
+      nasl_perror (lexic,
+                   "Syntax : prf(secret, seed, label, outlen)\n");
+      return NULL;
+    }
+  result = tls_prf (secret, secret_len, seed, seed_len, label, outlen, hmac);
+  if (!result)
+    return NULL;
+
+  retc = alloc_tree_cell (0, NULL);
+  retc->type = CONST_DATA;
+  retc->size = outlen;
+  retc->x.str_val = (char *) result;
+  return retc;
+}
+
+tree_cell *
+nasl_prf_sha256 (lex_ctxt * lexic)
+{
+  return nasl_prf (lexic, 0);
+}
+
+tree_cell *
+nasl_prf_sha384 (lex_ctxt * lexic)
+{
+  return nasl_prf (lexic, 1);
+}
+
+tree_cell *
+nasl_hmac_sha512 (lex_ctxt * lexic)
+{
+  return nasl_hmac (lexic, GCRY_MD_SHA512);
+}
+
 tree_cell *
 nasl_get_smb2_sign (lex_ctxt * lexic)
 {
@@ -343,13 +546,13 @@ nasl_ntlm2_response (lex_ctxt * lexic)
 {
   char *cryptkey = (char *) get_str_var_by_name (lexic, "cryptkey");
   char *password = get_str_var_by_name (lexic, "password");
-  unsigned char *nt_hash =
-    (unsigned char *) get_str_var_by_name (lexic, "nt_hash");
+  void *nt_hash = get_str_var_by_name (lexic, "nt_hash");
+  int hash_len = get_var_size_by_name (lexic, "nt_hash");
 
-  if (cryptkey == NULL || password == NULL)
+  if (!cryptkey || !password || !nt_hash || hash_len < 16)
     {
-      nasl_perror (lexic,
-                   "Syntax : ntlm2_response(cryptkey:<c>, password:<p>, nt_hash:<n>)\n");
+      nasl_perror
+       (lexic, "Syntax : ntlm2_response(cryptkey:<c>, password:<p>, nt_hash:<n[16]>)\n");
       return NULL;
     }
 
@@ -378,14 +581,14 @@ nasl_ntlm_response (lex_ctxt * lexic)
 {
   char *cryptkey = (char *) get_str_var_by_name (lexic, "cryptkey");
   char *password = get_str_var_by_name (lexic, "password");
-  unsigned char *nt_hash =
-    (unsigned char *) get_str_var_by_name (lexic, "nt_hash");
+  void *nt_hash = get_str_var_by_name (lexic, "nt_hash");
+  int hash_len = get_var_size_by_name (lexic, "nt_hash");
   int neg_flags = get_int_var_by_name (lexic, "neg_flags", -1);
 
-  if (cryptkey == NULL || password == NULL || nt_hash == NULL || neg_flags < 0)
+  if (!cryptkey || !password || !nt_hash || hash_len < 16 || neg_flags < 0)
     {
       nasl_perror (lexic,
-                   "Syntax : ntlm_response(cryptkey:<c>, password:<p>, nt_hash:<n>, neg_flags:<nf>)\n");
+                   "Syntax : ntlm_response(cryptkey:<c>, password:<p>, nt_hash:<n[16]>, neg_flags:<nf>)\n");
       return NULL;
     }
 
@@ -458,8 +661,11 @@ nasl_ntlmv1_hash (lex_ctxt * lexic)
       return NULL;
     }
 
+  if (pass_len < 16)
+    pass_len = 16;
+
   bzero (p21, sizeof (p21));
-  memcpy (p21, password, pass_len < 16 ? pass_len : 16);
+  memcpy (p21, password, pass_len);
 
   ret = g_malloc0 (24);
 
@@ -486,7 +692,7 @@ nasl_nt_owf_gen (lex_ctxt * lexic)
 
   if (pass_len < 0 || pass == NULL)
     {
-      nasl_perror (lexic, "Syntax : nt_owf_gen(cryptkey:<c>, password:<p>)\n");
+      nasl_perror (lexic, "Syntax : nt_owf_gen(password:<p>)\n");
       return NULL;
     }
 
@@ -525,7 +731,7 @@ nasl_lm_owf_gen (lex_ctxt * lexic)
 
   if (pass_len < 0 || pass == NULL)
     {
-      nasl_perror (lexic, "Syntax : nt_lm_gen(cryptkey:<c>, password:<p>)\n");
+      nasl_perror (lexic, "Syntax : nt_lm_gen(password:<p>)\n");
       return NULL;
     }
 
@@ -539,7 +745,7 @@ nasl_lm_owf_gen (lex_ctxt * lexic)
   retc = alloc_tree_cell (0, NULL);
   retc->type = CONST_DATA;
   retc->size = 16;
-  retc->x.str_val = g_memdup (p16, 17);
+  retc->x.str_val = g_memdup (p16, 16);
   return retc;
 }
 
