@@ -1,4 +1,4 @@
-/* Nessus Attack Scripting Language 
+/* Nessus Attack Scripting Language
  *
  * Copyright (C) 2002 - 2003 Michel Arboi and Renaud Deraison
  *
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef NASL_DEBUG_H__
@@ -21,6 +21,6 @@
 
 void nasl_perror (lex_ctxt *, char *, ...);
 void nasl_trace (lex_ctxt *, char *, ...);
-int nasl_trace_enabled ();
+int nasl_trace_enabled (void);
 
 #endif
