@@ -23,8 +23,8 @@
 #include <string.h>         /* for memset */
 #include <stdlib.h>         /* for getenv.  */
 
-#include "nvt_categories.h" /* for ACT_INIT */
-#include "network.h"      /* for OPENVAS_ENCAPS_* */
+#include "../misc/nvt_categories.h" /* for ACT_INIT */
+#include "../misc/network.h"      /* for OPENVAS_ENCAPS_* */
 
 #include "nasl.h"
 #include "nasl_tree.h"
@@ -73,11 +73,6 @@ static init_func libfuncs[] = {
   {"script_name", script_name, 1, {NULL}},
   {"script_version", script_version, 1, {NULL}},
   {"script_timeout", script_timeout, 1, {NULL}},
-
-  /* Can be removed once OpenVA-6 is retired and the command is
-     removed from any NVT */
-  {"script_description", script_description, 999, {NULL}},
-
   {"script_copyright", script_copyright, 999, {NULL}},
   {"script_summary", script_summary, 999, {NULL}},
   {"script_category", script_category, 1, {NULL}},
@@ -108,21 +103,10 @@ static init_func libfuncs[] = {
   {"replace_kb_item", replace_kb_item, 0, {"name", "value", NULL}},
   {"set_kb_item", set_kb_item, 0, {"name", "value", NULL}},
   {"get_kb_item", get_kb_item, 1, {NULL}},
-  {"get_kb_fresh_item", get_kb_fresh_item, 1, {NULL}},
   {"get_kb_list", get_kb_list, 1, {NULL}},
   {"security_message", security_message, 1,
    {"data", "port", "proto", "protocol", NULL}},
 
-  /* Once OpenVAS-5 is retired and the function calls are replaced
-     in all NASL scripts by security_message, these functions can removed
-     from the NASL API */
-  {"security_warning", security_message, 1,
-   {"data", "port", "proto", "protocol", NULL}},
-  {"security_note", security_message, 1,
-   {"data", "port", "proto", "protocol", NULL}},
-  {"security_hole", security_message, 1,
-   {"data", "port", "proto", "protocol", NULL}},
-
   {"log_message", log_message, 1, {"data", "port", "proto", "protocol", NULL}},
   {"error_message", error_message, 1,
    {"data", "port", "proto", "protocol", NULL}},
@@ -351,7 +335,12 @@ static init_func libfuncs[] = {
   {"HMAC_MD2", nasl_hmac_md2, 0, {"data", "key", NULL}},
   {"HMAC_MD5", nasl_hmac_md5, 0, {"data", "key", NULL}},
   {"HMAC_SHA1", nasl_hmac_sha1, 0, {"data", "key", NULL}},
+  {"HMAC_SHA256", nasl_hmac_sha256, 0, {"data", "key", NULL}},
+  {"HMAC_SHA384", nasl_hmac_sha384, 0, {"data", "key", NULL}},
+  {"HMAC_SHA512", nasl_hmac_sha512, 0, {"data", "key", NULL}},
   {"HMAC_RIPEMD160", nasl_hmac_ripemd160, 0, {"data", "key", NULL}},
+  {"prf_sha256", nasl_prf_sha256, 0, {"label", "outlen", "secret", "seed", NULL}},
+  {"prf_sha384", nasl_prf_sha384, 0, {"label", "outlen", "secret", "seed", NULL}},
   {"ntlmv2_response", nasl_ntlmv2_response, 0,
    {"address_list", "address_list_len", "crypt_key", "domain", "ntlmv2_hash",
     "user", NULL}},
@@ -373,16 +362,19 @@ static init_func libfuncs[] = {
    {"buf", "buflen", "key", "seq_number", NULL}},
   {"get_smb2_signature", nasl_get_smb2_sign, 0,
    {"buf", "key", NULL}},
-  {"hmac_sha256", nasl_hmac_sha256, 0,
-   {"buf", "buflen", "key", "keylen", NULL}},
   {"dh_generate_key", nasl_dh_generate_key, 0, {"g", "p", "priv", NULL}},
   {"bn_random", nasl_bn_random, 0, {"need", NULL}},
   {"bn_cmp", nasl_bn_cmp, 0, {"key1", "key2", NULL}},
   {"dh_compute_key", nasl_dh_compute_key, 0,
    {"dh_server_pub", "g", "p", "priv_key", "pub_key", NULL}},
+  {"rsa_public_encrypt", nasl_rsa_public_encrypt, 0, {"d", "data", "e", "n", "p", "q", NULL}},
   {"rsa_public_decrypt", nasl_rsa_public_decrypt, 0, {"e", "n", "sig", NULL}},
   {"bf_cbc_encrypt", nasl_bf_cbc_encrypt, 0, {"data", "iv", "key", NULL}},
   {"bf_cbc_decrypt", nasl_bf_cbc_decrypt, 0, {"data", "iv", "key", NULL}},
+  {"rc4_encrypt", nasl_rc4_encrypt, 0, {"data", "key", NULL}},
+  {"aes128_cbc_encrypt", nasl_aes128_cbc_encrypt, 0, {"data", "key", NULL}},
+  {"aes256_cbc_encrypt", nasl_aes256_cbc_encrypt, 0, {"data", "key", NULL}},
+  {"des_ede_cbc_encrypt", nasl_des_ede_cbc_encrypt, 0, {"data", "key", NULL}},
   {"dsa_do_verify", nasl_dsa_do_verify, 0,
    {"data", "g", "p", "pub", "q", "r", "s", NULL}},
   {"pem_to_rsa", nasl_pem_to_rsa, 0, {"passphrase", "priv", NULL}},
@@ -392,6 +384,7 @@ static init_func libfuncs[] = {
    {"data", "g", "p", "priv", "pub", "q", NULL}},
   {"gunzip", nasl_gunzip, 0, {"data", "len", NULL}},
   {"gzip", nasl_gzip, 0, {"data", "len", NULL}},
+  {"DES", nasl_cipher_des, 0, {"data", "key", NULL}},
 
 #ifdef HAVE_NETSNMP
   {"snmpv1_get", nasl_snmpv1_get, 0, {"community", "oid", "port", "protocol",
@@ -414,6 +407,7 @@ static init_func libfuncs[] = {
   {"ssh_shell_open", nasl_ssh_shell_open, 1, { NULL }},
   {"ssh_shell_read", nasl_ssh_shell_read, 1, { NULL }},
   {"ssh_shell_write", nasl_ssh_shell_write, 1, { "cmd" }},
+  {"ssh_shell_close", nasl_ssh_shell_close, 1, { NULL }},
   {"ssh_get_issue_banner", nasl_ssh_get_issue_banner, 1, {NULL }},
 #if LIBSSH_VERSION_INT >= SSH_VERSION_INT (0, 6, 0)
   {"ssh_get_server_banner", nasl_ssh_get_server_banner, 1, {NULL }},
@@ -626,7 +620,7 @@ static struct
   /* Since OpenVAS-8, libssh is mandatory. To maintain compatibility of
      the NVT feed with older versions, this variable needs to be set.
      Once OpenVAS-7 is retired, this setting of the variable can be removed
-     and also any occurances in the NVTs, which should lead to some
+     and also any occurrences in the NVTs, which should lead to some
      significant NASL code removals. */
   "_HAVE_LIBSSH", 1},
   {
@@ -719,8 +713,7 @@ char *
 nasl_version ()
 {
   static char vers[sizeof (OPENVASLIB_VERSION) + 1];
-  strncpy (vers, OPENVASLIB_VERSION, sizeof (vers) - 1);   /* Flawfinder: ignore
-                                                   (\0-termination taken care of) */
+  strncpy (vers, OPENVASLIB_VERSION, sizeof (vers) - 1);
   vers[sizeof (vers) - 1] = '\0';
   return vers;
 }
