@@ -1,4 +1,4 @@
-/* Nessus Attack Scripting Language 
+/* Nessus Attack Scripting Language
  *
  * Copyright (C) 2002 - 2004 Tenable Network Security
  *
@@ -13,11 +13,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
-#include "system.h"             /* for emalloc */
+#include <glib.h>  /* for g_free() */
 
 #include "nasl_func.h"
 #include "nasl_tree.h"
@@ -28,14 +28,15 @@
 lex_ctxt *
 init_empty_lex_ctxt ()
 {
-  lex_ctxt *c = emalloc (sizeof (lex_ctxt));
+  lex_ctxt *c = g_malloc0 (sizeof (lex_ctxt));
   int i;
 
-  c->ctx_vars.hash_elt = emalloc (sizeof (named_nasl_var) * VAR_NAME_HASH);
+  c->ctx_vars.hash_elt = g_malloc0 (sizeof (named_nasl_var) * VAR_NAME_HASH);
   c->ctx_vars.num_elt = NULL;
   c->ctx_vars.max_idx = 0;
   for (i = 0; i < FUNC_NAME_HASH; i++)
     c->functions[i] = NULL;
+  c->oid = NULL;
   c->ret_val = NULL;
   c->fct_ctxt = 0;
   return c;
@@ -56,17 +57,7 @@ free_lex_ctxt (lex_ctxt * c)
     {
       free_func_chain (c->functions[i]);
     }
-  efree (&c);
-}
-
-lex_ctxt *
-get_top_level_ctxt (lex_ctxt * ctxt)
-{
-  lex_ctxt *top = ctxt;
-
-  while (top->up_ctxt != NULL)
-    top = top->up_ctxt;
-  return top;
+  g_free (c);
 }
 
 void
