@@ -1,4 +1,4 @@
-/* Nessus Attack Scripting Language 
+/* Nessus Attack Scripting Language
  *
  * Copyright (C) 2002 - 2003 Michel Arboi and Renaud Deraison
  *
@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _NASL_LEX_CTXT_H
@@ -35,10 +35,11 @@ typedef struct struct_lex_ctxt
   unsigned fct_ctxt:1;          /* This is a function context */
   unsigned break_flag:1;        /* Break from loop */
   unsigned cont_flag:1;         /* Next iteration in loop */
-  unsigned authenticated:1;     /* Authenticated script */
   unsigned always_authenticated:1;
   struct arglist *script_infos;
+  const char *oid;
   int recv_timeout;
+  int line_nb;
   /* Named variables hash set + anonymous variables array */
   nasl_array ctx_vars;
   /* Functions hash set */
@@ -49,7 +50,6 @@ typedef struct struct_lex_ctxt
 
 lex_ctxt *init_empty_lex_ctxt (void);
 void free_lex_ctxt (lex_ctxt *);
-lex_ctxt *get_top_level_ctxt (lex_ctxt *);
 
 void dump_ctxt (lex_ctxt *);
 
