@@ -28,11 +28,11 @@
 #include <sys/time.h>           /* for gettimeofday */
 #include <unistd.h>             /* for usleep */
 
-#include "ftp_funcs.h"          /* for ftp_log_in */
-#include "kb.h"                 /* for KB_TYPE_STR */
-#include "network.h"            /* read_stream_connection_min */
-#include "plugutils.h"          /* plug_get_host_open_port */
-#include "openvas_compress.h"
+#include "../misc/ftp_funcs.h"          /* for ftp_log_in */
+#include "../base/kb.h"                 /* for KB_TYPE_STR */
+#include "../misc/network.h"            /* read_stream_connection_min */
+#include "../misc/plugutils.h"          /* plug_get_host_open_port */
+#include "../base/openvas_compress.h"
 
 #include "nasl_tree.h"
 #include "nasl_global_ctxt.h"
@@ -58,7 +58,7 @@ nasl_rand (lex_ctxt * lexic)
   tree_cell *retc;
   retc = alloc_tree_cell (0, NULL);
   retc->type = CONST_INT;
-  retc->x.i_val = lrand48 ();   /* RATS: ignore */
+  retc->x.i_val = lrand48 ();
   return retc;
 }
 
@@ -387,7 +387,7 @@ nasl_make_list (lex_ctxt * lexic)
   retc->type = DYN_ARRAY;
   retc->x.ref_val = a = g_malloc0 (sizeof (nasl_array));
 
-  for (i = vi = 0; (v = nasl_get_var_by_num (&lexic->ctx_vars, vi, 0)) != NULL;
+  for (i = vi = 0; (v = nasl_get_var_by_num (lexic, &lexic->ctx_vars, vi, 0)) != NULL;
        vi++)
     {
       switch (v->var_type)
@@ -457,9 +457,9 @@ nasl_make_array (lex_ctxt * lexic)
   retc->x.ref_val = a = g_malloc0 (sizeof (nasl_array));
 
   vi = 0;
-  while ((v = nasl_get_var_by_num (&lexic->ctx_vars, vi++, 0)) != NULL)
+  while ((v = nasl_get_var_by_num (lexic, &lexic->ctx_vars, vi++, 0)) != NULL)
     {
-      v2 = nasl_get_var_by_num (&lexic->ctx_vars, vi++, 0);
+      v2 = nasl_get_var_by_num (lexic, &lexic->ctx_vars, vi++, 0);
       if (v2 == NULL)
         {
           nasl_perror (lexic, "make_array: odd number (%d) of argument?\n", vi);
@@ -509,7 +509,7 @@ nasl_keys (lex_ctxt * lexic)
 
   bzero (&myvar, sizeof (myvar));
 
-  for (i = vi = 0; (v = nasl_get_var_by_num (&lexic->ctx_vars, vi, 0)) != NULL;
+  for (i = vi = 0; (v = nasl_get_var_by_num (lexic, &lexic->ctx_vars, vi, 0)) != NULL;
        vi++)
     {
       if (v->var_type == VAR2_ARRAY)
@@ -549,7 +549,7 @@ nasl_max_index (lex_ctxt * lexic)
   anon_nasl_var *v;
   nasl_array *a;
 
-  v = nasl_get_var_by_num (&lexic->ctx_vars, 0, 0);
+  v = nasl_get_var_by_num (lexic, &lexic->ctx_vars, 0, 0);
   if (v == NULL)
     return NULL;
   if (v->var_type != VAR2_ARRAY)
@@ -573,7 +573,7 @@ nasl_typeof (lex_ctxt * lexic)
 
   retc = alloc_tree_cell (0, NULL);
   retc->type = CONST_DATA;
-  u = nasl_get_var_by_num (&lexic->ctx_vars, 0, 0);
+  u = nasl_get_var_by_num (lexic, &lexic->ctx_vars, 0, 0);
 
   if (u == NULL)
     s = "null";
@@ -809,7 +809,7 @@ nasl_gettimeofday (lex_ctxt * lexic)
   retc = alloc_typed_cell (CONST_DATA);
   retc->size = strlen (str);
   retc->x.str_val = g_malloc0 (retc->size);
-  strcpy (retc->x.str_val, str);        /* Flawfinder: ignore */
+  strcpy (retc->x.str_val, str);
   return retc;
 }
 
