@@ -56,12 +56,13 @@
 #include "nasl_var.h"
 #include "nasl_lex_ctxt.h"
 #include "exec.h"
-#include "plugutils.h"
-#include "kb.h"
+#include "../misc/plugutils.h"
+#include "../base/kb.h"
 #include "nasl_debug.h"
-#include "network.h"            /* for openvas_get_socket_from_connection */
+#include "../misc/network.h"            /* for openvas_get_socket_from_connection */
 #include "../misc/openvas_logging.h"
 #include "../misc/prefs.h"  /* for prefs_get() */
+#include "../misc/openvas_ssh.h"
 
 #include "nasl_ssh.h"
 
@@ -209,13 +210,7 @@ my_ssh_pki_import_privkey_base64(ssh_session session,
   char *pkcs8_buffer = NULL;
 
   /* Write the private key to a file in a temporary directory.  */
-  if (
-#if GLIB_CHECK_VERSION (2,30,0)
-      !g_mkdtemp_full (key_dir, S_IRUSR|S_IWUSR|S_IXUSR)
-#else
-      !mkdtemp (key_dir)
-#endif
-      )
+  if (!g_mkdtemp_full (key_dir, S_IRUSR|S_IWUSR|S_IXUSR))
     {
       log_legacy_write ("%s: g_mkdtemp_full/mkdtemp failed\n", __FUNCTION__);
       return SSH_AUTH_ERROR;
@@ -491,7 +486,7 @@ nasl_ssh_connect (lex_ctxt *lexic)
 {
   ssh_session session;
   tree_cell *retc;
-  const char *hostname, *key_type;
+  const char *hostname, *key_type, *csciphers, *scciphers;
   int port, sock;
   int tbl_slot;
   const char *s;
@@ -562,6 +557,23 @@ nasl_ssh_connect (lex_ctxt *lexic)
     }
 #endif
 
+  csciphers = get_str_local_var_by_name (lexic, "csciphers");
+  if (csciphers && ssh_options_set (session, SSH_OPTIONS_CIPHERS_C_S, csciphers))
+    {
+      log_legacy_write ("Failed to set SSH client to server ciphers '%s': %s",
+                        csciphers, ssh_get_error (session));
+      ssh_free (session);
+      return NULL;
+    }
+  scciphers = get_str_local_var_by_name (lexic, "scciphers");
+  if (scciphers && ssh_options_set (session, SSH_OPTIONS_CIPHERS_S_C, scciphers))
+    {
+      log_legacy_write ("Failed to set SSH server to client ciphers '%s': %s",
+                        scciphers, ssh_get_error (session));
+      ssh_free (session);
+      return NULL;
+    }
+
   if (port)
     {
       unsigned int my_port = port;
@@ -656,12 +668,9 @@ nasl_ssh_connect (lex_ctxt *lexic)
    returned, on success the session id and in this case the slot number
    from the table is stored at R_SLOT.  */
 static int
-find_session_id (lex_ctxt *lexic, const char *funcname, int *r_slot)
+verify_session_id (int session_id, const char *funcname, int *r_slot)
 {
   int tbl_slot;
-  int session_id;
-
-  session_id = get_int_var_by_num (lexic, 0, -1);
   if (session_id <= 0)
     {
       if (funcname)
@@ -690,7 +699,7 @@ static void
 do_nasl_ssh_disconnect (int tbl_slot)
 {
   if (session_table[tbl_slot].channel)
-    ssh_channel_close (session_table[tbl_slot].channel);
+    ssh_channel_free (session_table[tbl_slot].channel);
   ssh_disconnect (session_table[tbl_slot].session);
   ssh_free (session_table[tbl_slot].session);
   session_table[tbl_slot].session_id = 0;
@@ -726,8 +735,8 @@ nasl_ssh_disconnect (lex_ctxt *lexic)
   int tbl_slot;
   int session_id;
 
-  session_id = find_session_id (lexic, NULL, &tbl_slot);
-  if (!session_id)
+  session_id = get_int_var_by_num (lexic, 0, -1);
+  if (!verify_session_id (session_id, NULL, &tbl_slot))
     return FAKE_CELL;
   do_nasl_ssh_disconnect (tbl_slot);
   return FAKE_CELL;
@@ -744,7 +753,7 @@ nasl_ssh_disconnect (lex_ctxt *lexic)
  * (libssh takes ownership of the socket if set via SSH_OPTIONS_FD).
  * This function implements the hook for checking and closing.
  *
- * @param[in] A socket
+ * @param[in] sock A socket
  *
  * @return Zero if the socket was closed (disconnected).
  */
@@ -830,10 +839,11 @@ nasl_ssh_session_id_from_sock (lex_ctxt *lexic)
 tree_cell *
 nasl_ssh_get_sock (lex_ctxt *lexic)
 {
-  int tbl_slot, sock;
+  int tbl_slot, sock, session_id;
   tree_cell *retc;
 
-  if (!find_session_id (lexic, "ssh_get_sock", &tbl_slot))
+  session_id = get_int_var_by_num (lexic, 0, -1);
+  if (!verify_session_id (session_id, "ssh_get_sock", &tbl_slot))
     sock = -1;
   else
     sock = session_table[tbl_slot].sock;
@@ -941,9 +951,10 @@ get_authmethods (int tbl_slot)
 tree_cell *
 nasl_ssh_set_login (lex_ctxt *lexic)
 {
-  int tbl_slot;
+  int tbl_slot, session_id;
 
-  if (!find_session_id (lexic, "ssh_set_login", &tbl_slot))
+  session_id = get_int_var_by_num (lexic, 0, -1);
+  if (!verify_session_id (session_id, "ssh_set_login", &tbl_slot))
     return NULL;  /* Ooops.  */
   if (!session_table[tbl_slot].user_set)
     {
@@ -1043,8 +1054,8 @@ nasl_ssh_userauth (lex_ctxt *lexic)
   int methods;
   int verbose;
 
-  session_id = find_session_id (lexic, "ssh_userauth", &tbl_slot);
-  if (!session_id)
+  session_id = get_int_var_by_num (lexic, 0, -1);
+  if (!verify_session_id (session_id, "ssh_userauth", &tbl_slot))
     return NULL;  /* Ooops.  */
   session = session_table[tbl_slot].session;
   verbose = session_table[tbl_slot].verbose;
@@ -1230,6 +1241,12 @@ nasl_ssh_userauth (lex_ctxt *lexic)
   }
 }
 
+static void
+exec_ssh_cmd_alarm (int signal)
+{
+  log_legacy_write ("exec_ssh_cmd: Timeout");
+}
+
 /**
  * @brief Execute an ssh command.
  *
@@ -1253,6 +1270,9 @@ exec_ssh_cmd (ssh_session session, char *cmd, int verbose, int compat_mode,
   int rc, retry = 60;
   ssh_channel channel;
 
+  /* Work-around for LibSSH calling poll() with an infinite timeout. */
+  signal (SIGALRM, exec_ssh_cmd_alarm);
+  alarm (30);
   if ((channel = ssh_channel_new (session)) == NULL)
     {
       log_legacy_write ("ssh_channel_new failed: %s\n",
@@ -1276,10 +1296,11 @@ exec_ssh_cmd (ssh_session session, char *cmd, int verbose, int compat_mode,
       if (verbose)
         log_legacy_write ("ssh_channel_request_exec failed for '%s': %s\n",
                           cmd, ssh_get_error (session));
-      ssh_channel_close (channel);
       ssh_channel_free (channel);
       return SSH_ERROR;
     }
+  alarm (0);
+  signal (SIGALRM, _exit);
   /* XXX: ssh_channel_read_timeout() is available for LIBSSH > 0.6. */
   while (ssh_channel_is_open (channel) && !ssh_channel_is_eof (channel)
          && retry-- > 0)
@@ -1314,8 +1335,6 @@ exec_ssh_cmd (ssh_session session, char *cmd, int verbose, int compat_mode,
   rc = SSH_OK;
 
 exec_err:
-  ssh_channel_send_eof (channel);
-  ssh_channel_close (channel);
   ssh_channel_free (channel);
   return rc;
 }
@@ -1386,8 +1405,8 @@ nasl_ssh_request_exec (lex_ctxt *lexic)
   char *p;
   int to_stdout, to_stderr, compat_mode, compat_buf_inuse;
 
-  session_id = find_session_id (lexic, "ssh_request_exec", &tbl_slot);
-  if (!session_id)
+  session_id = get_int_var_by_num (lexic, 0, -1);
+  if (!verify_session_id (session_id, "ssh_request_exec", &tbl_slot))
     return NULL;
   session = session_table[tbl_slot].session;
 
@@ -1494,12 +1513,13 @@ nasl_ssh_request_exec (lex_ctxt *lexic)
 tree_cell *
 nasl_ssh_get_issue_banner (lex_ctxt *lexic)
 {
-  int tbl_slot;
+  int tbl_slot, session_id;
   ssh_session session;
   char *banner;
   tree_cell *retc;
 
-  if (!find_session_id (lexic, "ssh_get_issue_banner", &tbl_slot))
+  session_id = get_int_var_by_num (lexic, 0, -1);
+  if (!verify_session_id (session_id, "ssh_get_issue_banner", &tbl_slot))
     return NULL;
   session = session_table[tbl_slot].session;
 
@@ -1544,12 +1564,13 @@ nasl_ssh_get_issue_banner (lex_ctxt *lexic)
 tree_cell *
 nasl_ssh_get_server_banner (lex_ctxt *lexic)
 {
-  int tbl_slot;
+  int tbl_slot, session_id;
   ssh_session session;
   const char *banner;
   tree_cell *retc;
 
-  if (!find_session_id (lexic, "ssh_get_server_banner", &tbl_slot))
+  session_id = get_int_var_by_num (lexic, 0, -1);
+  if (!verify_session_id (session_id, "ssh_get_server_banner", &tbl_slot))
     return NULL;
   session = session_table[tbl_slot].session;
 
@@ -1586,12 +1607,13 @@ nasl_ssh_get_server_banner (lex_ctxt *lexic)
 tree_cell *
 nasl_ssh_get_host_key (lex_ctxt *lexic)
 {
-  int tbl_slot;
+  int tbl_slot, session_id;
   ssh_session session;
   ssh_string sstring;
   tree_cell *retc;
 
-  if (!find_session_id (lexic, "ssh_get_host_key", &tbl_slot))
+  session_id = get_int_var_by_num (lexic, 0, -1);
+  if (!verify_session_id (session_id, "ssh_get_host_key", &tbl_slot))
     return NULL;
   session = session_table[tbl_slot].session;
 
@@ -1629,13 +1651,13 @@ nasl_ssh_get_host_key (lex_ctxt *lexic)
 tree_cell *
 nasl_ssh_get_auth_methods (lex_ctxt *lexic)
 {
-  int tbl_slot;
-  int methods;
+  int tbl_slot, methods, session_id;
   GString *buffer;
   char *p;
   tree_cell *retc;
 
-  if (!find_session_id (lexic, "ssh_get_auth_methods", &tbl_slot))
+  session_id = get_int_var_by_num (lexic, 0, -1);
+  if (!verify_session_id (session_id, "ssh_get_auth_methods", &tbl_slot))
     return NULL;
 
   if (!session_table[tbl_slot].user_set && !nasl_ssh_set_login (lexic))
@@ -1667,6 +1689,12 @@ nasl_ssh_get_auth_methods (lex_ctxt *lexic)
   return retc;
 }
 
+static void
+request_ssh_shell_alarm (int signal)
+{
+  log_legacy_write ("request_ssh_shell: Timeout");
+}
+
 /**
  * @brief Open a shell on an ssh channel.
  *
@@ -1678,12 +1706,19 @@ static int
 request_ssh_shell (ssh_channel channel)
 {
   assert (channel);
+
+  /* Work-around for LibSSH calling poll() with an infinite timeout. */
+  signal (SIGALRM, request_ssh_shell_alarm);
+  alarm (30);
   if (ssh_channel_request_pty (channel))
     return -1;
   if (ssh_channel_change_pty_size (channel, 80, 24))
     return -1;
   if (ssh_channel_request_shell (channel))
     return -1;
+  alarm (0);
+  signal (SIGALRM, _exit);
+
   return 0;
 }
 
@@ -1704,12 +1739,13 @@ request_ssh_shell (ssh_channel channel)
 tree_cell *
 nasl_ssh_shell_open (lex_ctxt *lexic)
 {
-  int tbl_slot;
+  int tbl_slot, session_id;
   ssh_channel channel;
   ssh_session session;
   tree_cell *retc;
 
-  if (!find_session_id (lexic, "ssh_shell_open", &tbl_slot))
+  session_id = get_int_var_by_num (lexic, 0, -1);
+  if (!verify_session_id (session_id, "ssh_shell_open", &tbl_slot))
     return NULL;
   session = session_table[tbl_slot].session;
   channel = ssh_channel_new (session);
@@ -1717,19 +1753,20 @@ nasl_ssh_shell_open (lex_ctxt *lexic)
     return NULL;
   if (ssh_channel_open_session (channel))
     {
-      log_legacy_write ("ssh_shell_open: Couldn't open ssh shell");
+      log_legacy_write ("ssh_channel_open_session: %s",
+                        ssh_get_error (session));
       ssh_channel_free (channel);
       return NULL;
     }
 
   if (request_ssh_shell (channel))
     {
-      log_legacy_write ("ssh_shell_open: Couldn't open ssh shell");
+      log_legacy_write ("request_ssh_shell: %s", ssh_get_error (session));
       ssh_channel_free (channel);
       return NULL;
     }
   if (session_table[tbl_slot].channel)
-    ssh_channel_close (session_table[tbl_slot].channel);
+    ssh_channel_free (session_table[tbl_slot].channel);
   session_table[tbl_slot].channel = channel;
 
   retc = alloc_typed_cell (CONST_INT);
@@ -1784,12 +1821,13 @@ read_ssh_nonblocking (ssh_channel channel, GString *response)
 tree_cell *
 nasl_ssh_shell_read (lex_ctxt *lexic)
 {
-  int tbl_slot;
+  int tbl_slot, session_id;
   ssh_channel channel;
   tree_cell *retc;
   GString *response;
 
-  if (!find_session_id (lexic, "ssh_shell_read", &tbl_slot))
+  session_id = get_int_var_by_num (lexic, 0, -1);
+  if (!verify_session_id (session_id, "ssh_shell_read", &tbl_slot))
     return NULL;
   channel = session_table[tbl_slot].channel;
 
@@ -1820,12 +1858,13 @@ nasl_ssh_shell_read (lex_ctxt *lexic)
 tree_cell *
 nasl_ssh_shell_write (lex_ctxt *lexic)
 {
-  int tbl_slot, rc = -1, len;
+  int tbl_slot, rc = -1, len, session_id;
   ssh_channel channel;
   tree_cell *retc;
   char *cmd;
 
-  if (!find_session_id (lexic, "ssh_shell_write", &tbl_slot))
+  session_id = get_int_var_by_num (lexic, 0, -1);
+  if (!verify_session_id (session_id, "ssh_shell_write", &tbl_slot))
     goto write_ret;
   if (!(channel = session_table[tbl_slot].channel))
     {
@@ -1842,7 +1881,8 @@ nasl_ssh_shell_write (lex_ctxt *lexic)
   len = strlen (cmd);
   if (ssh_channel_write (channel, cmd, len) != len)
     {
-      log_legacy_write ("ssh_shell_write: Error writing to shell");
+      log_legacy_write ("ssh_shell_write: %s",
+                        ssh_get_error (session_table[tbl_slot].session));
       goto write_ret;
     }
   rc = 0;
@@ -1852,3 +1892,31 @@ write_ret:
   retc->x.i_val = rc;
   return retc;
 }
+
+/**
+ * @brief Close an ssh shell.
+ * @naslfn{ssh_shell_close}
+ *
+ * @nasluparam
+ *
+ * - An ssh session id.
+ *
+ * @param[in] lexic Lexical context of NASL interpreter.
+ */
+tree_cell *
+nasl_ssh_shell_close (lex_ctxt *lexic)
+{
+  int tbl_slot, session_id;
+
+  session_id = get_int_var_by_num (lexic, 0, -1);
+  if (!verify_session_id (session_id, "ssh_shell_close", &tbl_slot))
+    return NULL;
+  if (session_table[tbl_slot].channel)
+    {
+      ssh_channel_free (session_table[tbl_slot].channel);
+      session_table[tbl_slot].channel = NULL;
+    }
+
+  return NULL;
+}
+
