@@ -68,14 +68,14 @@ hash_str (const char *s)
 }
 
 anon_nasl_var *
-nasl_get_var_by_num (nasl_array * a, int num, int create)
+nasl_get_var_by_num (void *ctxt, nasl_array *a, int num, int create)
 {
   anon_nasl_var *v = NULL;
 
   if (num < 0)
     {
       /* TBD: implement a min_index field, just like $[ in Perl */
-      nasl_perror (NULL, "Negative integer index are not supported yet!\n");
+      nasl_perror (ctxt, "Negative integer index are not supported yet!\n");
       return NULL;
     }
 
@@ -229,7 +229,7 @@ get_var_name (anon_nasl_var * v)
   if (v->av_name != NULL)
     return v->av_name;
 #endif
-  snprintf (str, sizeof (str), "[%p]", v);      /* RATS: ignore */
+  snprintf (str, sizeof (str), "[%p]", v);
   return str;
 }
 
@@ -280,7 +280,7 @@ get_array_elem (lex_ctxt * ctxt, const char *name, tree_cell * idx)
       switch (idx->type)
         {
         case CONST_INT:
-          av = nasl_get_var_by_num (&u->v.v_arr, idx->x.i_val,
+          av = nasl_get_var_by_num (ctxt, &u->v.v_arr, idx->x.i_val,
                                     /* avoid dangling pointers */
                                     strcmp (name, "_FCT_ANON_ARGS"));
           return var2cell (av);
@@ -379,7 +379,6 @@ free_array (nasl_array * a)
         free_var_chain (a->hash_elt[i]);
       g_free (a->hash_elt);
       a->hash_elt = NULL;
-      a->num_elt = NULL;
     }
 }
 
@@ -1150,25 +1149,25 @@ array2str (const nasl_array * a)
           switch (u->var_type)
             {
             case VAR2_INT:
-              snprintf (s + n, len - n, "%d: %d", i, u->v.v_int);       /* RATS: ignore */
+              snprintf (s + n, len - n, "%d: %ld", i, u->v.v_int);
               n += strlen (s + n);
               break;
             case VAR2_STRING:
             case VAR2_DATA:
               if (u->v.v_str.s_siz < 64)
                 {
-                  snprintf (s + n, len - n, "%d: '%s'", i, u->v.v_str.s_val);   /* RATS: ignore */
+                  snprintf (s + n, len - n, "%d: '%s'", i, u->v.v_str.s_val);
                   n += strlen (s + n);
                 }
               else
                 {
-                  snprintf (s + n, 70, "%d: '%s", i, u->v.v_str.s_val); /* RATS: ignore */
+                  snprintf (s + n, 70, "%d: '%s", i, u->v.v_str.s_val);
                   n += strlen (s + n);
                   n += sprintf (s + n, "'...");
                 }
               break;
             default:
-              snprintf (s + n, len - n, "%d: ????", i); /* RATS: ignore */
+              snprintf (s + n, len - n, "%d: ????", i);
               n += strlen (s + n);
               break;
             }
@@ -1192,24 +1191,24 @@ array2str (const nasl_array * a)
             switch (u->var_type)
               {
               case VAR2_INT:
-                n += snprintf (s + n, len - n, "%s: %d", v->var_name, u->v.v_int);      /* RATS: ignore */
+                n += snprintf (s + n, len - n, "%s: %ld", v->var_name, u->v.v_int);
                 break;
               case VAR2_STRING:
               case VAR2_DATA:
                 if (u->v.v_str.s_siz < 64)
                   {
-                    snprintf (s + n, len - n, "%s: '%s'", v->var_name, u->v.v_str.s_val);       /* RATS: ignore */
+                    snprintf (s + n, len - n, "%s: '%s'", v->var_name, u->v.v_str.s_val);
                     n += strlen (s + n);
                   }
                 else
                   {
-                    snprintf (s + n, 70 + l, "%s: '%s", v->var_name, u->v.v_str.s_val); /* RATS: ignore */
+                    snprintf (s + n, 70 + l, "%s: '%s", v->var_name, u->v.v_str.s_val);
                     n += strlen (s + n);
                     n += sprintf (s + n, "'...");
                   }
                 break;
               default:
-                snprintf (s + n, len - n, "%s: ????", v->var_name);     /* RATS: ignore */
+                snprintf (s + n, len - n, "%s: ????", v->var_name);
                 n += strlen (s + n);
                 break;
               }
@@ -1235,7 +1234,7 @@ var2str (const anon_nasl_var * v)
   switch (v->var_type)
     {
     case VAR2_INT:
-      snprintf (s1, sizeof (s1), "%d", v->v.v_int);     /* RATS: ignore */
+      snprintf (s1, sizeof (s1), "%ld", v->v.v_int);
       return s1;                /* buggy if called twice in a row */
 
     case VAR2_STRING:
@@ -1365,7 +1364,7 @@ get_local_var_type_by_name (lex_ctxt * lexic, const char *name)
 }
 
 nasl_iterator
-nasl_array_iterator (tree_cell * c)
+nasl_array_iterator (void *ctxt, tree_cell * c)
 {
   nasl_iterator it;
   anon_nasl_var *v;
@@ -1391,7 +1390,7 @@ nasl_array_iterator (tree_cell * c)
     }
   else
     {
-      nasl_perror (NULL, "nasl_array_iterator: unhandled type %d (0x%x)\n",
+      nasl_perror (ctxt, "nasl_array_iterator: unhandled type %d (0x%x)\n",
                    c->type, c->type);
     }
 
