@@ -10,9 +10,10 @@
  * Copyright:
  * Copyright (c) 2009 Greenbone Networks GmbH, http://www.greenbone.net
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2
- * (or any later version), as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -37,7 +38,7 @@
 
 typedef int SMB_HANDLE;
 
-char *smb_versioninfo ();
+char *smb_versioninfo (void);
 int smb_connect (const char *, const char *, const char *, const char *,
                  SMB_HANDLE *);
 int smb_close (SMB_HANDLE);
@@ -45,5 +46,6 @@ char *smb_file_SDDL (SMB_HANDLE, const char *);
 char *smb_file_OwnerSID (SMB_HANDLE, const char *);
 char *smb_file_GroupSID (SMB_HANDLE, const char *);
 char *smb_file_TrusteeRights (SMB_HANDLE, const char *);
+int wincmd(int argc, char *argv[], char **res);
 
 #endif
