@@ -48,7 +48,7 @@
 
 #include "omp.h"
 #include "xml.h"
-#include "openvas_server.h"
+#include "../misc/openvas_server.h"
 
 #undef G_LOG_DOMAIN
 /**
@@ -209,8 +209,8 @@ omp_authenticate (gnutls_session_t* session,
                                         "<username>%s</username>"
                                         "<password>%s</password>"
                                         "</credentials></authenticate>",
-                                        username,
-                                        password);
+                                        username ? username : "",
+                                        password ? password : "");
   if (ret)
     return ret;
 
@@ -325,6 +325,98 @@ omp_authenticate_info_ext (gnutls_session_t *session,
   return 2;
 }
 
+/**
+ * @brief Authenticate with the manager.
+ *
+ * @param[in]  connection  Connection
+ * @param[in]  opts        Struct containing the options to apply.
+ *
+ * @return 0 on success, 1 if manager closed connection, 2 if auth failed,
+ *         3 on timeout, -1 on error.
+ */
+int
+omp_authenticate_info_ext_c (openvas_connection_t *connection,
+                             omp_authenticate_info_opts_t opts)
+{
+  entity_t entity;
+  const char* status;
+  char first;
+  int ret;
+
+  if (opts.timezone)
+    *(opts.timezone) = NULL;
+
+  /* Send the auth request. */
+
+  ret = openvas_connection_sendf_xml_quiet (connection,
+                                            "<authenticate>"
+                                            "<credentials>"
+                                            "<username>%s</username>"
+                                            "<password>%s</password>"
+                                            "</credentials>"
+                                            "</authenticate>",
+                                            opts.username,
+                                            opts.password);
+  if (ret)
+    return ret;
+
+  /* Read the response. */
+
+  entity = NULL;
+  switch (try_read_entity_c (connection, opts.timeout, &entity))
+    {
+      case 0:
+        break;
+      case -4:
+        return 3;
+      default:
+        return -1;
+    }
+
+  /* Check the response. */
+
+  status = entity_attribute (entity, "status");
+  if (status == NULL)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  if (strlen (status) == 0)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  first = status[0];
+  if (first == '2')
+    {
+      entity_t timezone_entity, role_entity, severity_entity;
+      /* Get the extra info. */
+      timezone_entity = entity_child (entity, "timezone");
+      if (timezone_entity && opts.timezone)
+        *opts.timezone = g_strdup (entity_text (timezone_entity));
+      role_entity = entity_child (entity, "role");
+      if (role_entity && opts.role)
+        *opts.role = g_strdup (entity_text (role_entity));
+      severity_entity = entity_child (entity, "severity");
+      if (severity_entity && opts.severity)
+        *opts.severity = g_strdup (entity_text (severity_entity));
+      if (opts.pw_warning)
+        {
+          entity_t pw_warn_entity;
+          pw_warn_entity = entity_child (entity, "password_warning");
+          if (pw_warn_entity)
+            *(opts.pw_warning) = g_strdup (entity_text (pw_warn_entity));
+          else
+            *(opts.pw_warning) = NULL;
+        }
+
+      free_entity (entity);
+      return 0;
+    }
+  free_entity (entity);
+  return 2;
+}
+
 /**
  * @brief Create a task.
  *
@@ -376,10 +468,10 @@ omp_create_task_ext (gnutls_session_t* session,
   else
     scanner = NULL;
 
-  if (opts.scanner_id)
+  if (opts.schedule_id)
     schedule = g_strdup_printf ("<schedule id=\"%s\"/>"
                                 "<schedule_periods>%d</schedule_periods>",
-                                opts.scanner_id,
+                                opts.schedule_id,
                                 opts.schedule_periods);
   else
     schedule = NULL;
@@ -453,7 +545,7 @@ omp_create_task_ext (gnutls_session_t* session,
 
   if (opts.alert_ids)
     {
-      int i;
+      unsigned int i;
       alerts = g_string_new ("");
       for (i = 0; i < opts.alert_ids->len; i++)
         {
@@ -476,7 +568,7 @@ omp_create_task_ext (gnutls_session_t* session,
 
       if (opts.observer_groups)
         {
-          int i;
+          unsigned int i;
           for (i = 0; i < opts.observer_groups->len; i++)
             {
               char *group = (char*) g_ptr_array_index (opts.observer_groups, i);
@@ -623,6 +715,68 @@ omp_start_task_report (gnutls_session_t* session, const char* task_id,
   return 1;
 }
 
+/**
+ * @brief Start a task and read the manager response.
+ *
+ * @param[in]   connection  Connection.
+ * @param[in]   task_id     ID of task.
+ * @param[out]  report_id   ID of report.
+ *
+ * @return 0 on success, 1 on failure, -1 on error.
+ */
+int
+omp_start_task_report_c (openvas_connection_t *connection, const char *task_id,
+                         char **report_id)
+{
+  entity_t entity;
+  const char *status;
+  char first;
+
+  if (openvas_connection_sendf (connection,
+                                "<start_task task_id=\"%s\"/>",
+                                task_id)
+      == -1)
+    return -1;
+
+  /* Read the response. */
+
+  entity = NULL;
+  if (read_entity_c (connection, &entity)) return -1;
+
+  /* Check the response. */
+
+  status = entity_attribute (entity, "status");
+  if (status == NULL)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  if (strlen (status) == 0)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  first = status[0];
+  if (first == '2')
+    {
+      if (report_id)
+        {
+          entity_t report_id_xml = entity_child (entity, "report_id");
+          if (report_id_xml)
+            *report_id = g_strdup (entity_text (report_id_xml));
+          else
+            {
+              free_entity (entity);
+              return -1;
+            }
+        }
+      free_entity (entity);
+      return 0;
+    }
+  free_entity (entity);
+  return 1;
+}
+
 /** @todo Use this in the other functions. */
 /**
  * @brief Read response and convert status of response to a return value.
@@ -667,6 +821,49 @@ check_response (gnutls_session_t* session)
   return ret;
 }
 
+/**
+ * @brief Read response and convert status of response to a return value.
+ *
+ * @param[in]  session  Pointer to GNUTLS session.
+ *
+ * @return 0 on success, -1 or OMP response code on error.
+ */
+int
+check_response_c (openvas_connection_t *connection)
+{
+  int ret;
+  const char* status;
+  entity_t entity;
+
+  /* Read the response. */
+
+  entity = NULL;
+  if (read_entity_c (connection, &entity)) return -1;
+
+  /* Check the response. */
+
+  status = entity_attribute (entity, "status");
+  if (status == NULL)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  if (strlen (status) == 0)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  if (status[0] == '2')
+    {
+      free_entity (entity);
+      return 0;
+    }
+  ret = (int) strtol (status, NULL, 10);
+  free_entity (entity);
+  if (errno == ERANGE) return -1;
+  return ret;
+}
+
 /**
  * @brief Read response status and resource UUID.
  *
@@ -743,6 +940,26 @@ omp_stop_task (gnutls_session_t* session, const char* id)
   return check_response (session);
 }
 
+/**
+ * @brief Stop a task and read the manager response.
+ *
+ * @param[in]  session  Pointer to GNUTLS session.
+ * @param[in]  id       ID of task.
+ *
+ * @return 0 on success, OMP response code on failure, -1 on error.
+ */
+int
+omp_stop_task_c (openvas_connection_t *connection, const char* id)
+{
+  if (openvas_connection_sendf (connection,
+                                "<stop_task task_id=\"%s\"/>",
+                                id)
+      == -1)
+    return -1;
+
+  return check_response_c (connection);
+}
+
 /**
  * @brief Resume a task and read the manager response.
  *
@@ -801,6 +1018,64 @@ omp_resume_task_report (gnutls_session_t* session, const char* task_id,
   return 1;
 }
 
+/**
+ * @brief Resume a task and read the manager response.
+ *
+ * @param[in]   connection  Connection.
+ * @param[in]   task_id     ID of task.
+ * @param[out]  report_id   ID of report.
+ *
+ * @return 0 on success, 1 on OMP failure, -1 on error.
+ */
+int
+omp_resume_task_report_c (openvas_connection_t *connection, const char* task_id,
+                          char** report_id)
+{
+  if (openvas_connection_sendf (connection,
+                                "<resume_task task_id=\"%s\"/>",
+                                task_id)
+      == -1)
+    return -1;
+
+  /* Read the response. */
+
+  entity_t entity = NULL;
+  if (read_entity_c (connection, &entity)) return -1;
+
+  /* Check the response. */
+
+  const char* status = entity_attribute (entity, "status");
+  if (status == NULL)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  if (strlen (status) == 0)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  char first = status[0];
+  if (first == '2')
+    {
+      if (report_id)
+        {
+          entity_t report_id_xml = entity_child (entity, "report_id");
+          if (report_id_xml)
+            *report_id = g_strdup (entity_text (report_id_xml));
+          else
+            {
+              free_entity (entity);
+              return -1;
+            }
+        }
+      free_entity (entity);
+      return 0;
+    }
+  free_entity (entity);
+  return 1;
+}
+
 /**
  * @brief Delete a task and read the manager response.
  *
@@ -842,6 +1117,7 @@ omp_get_tasks (gnutls_session_t* session, const char* id, int details,
   const char* status_code;
   int ret;
 
+  (void) include_rcfile;
   if (id == NULL)
     {
       if (openvas_server_sendf (session,
@@ -1108,6 +1384,7 @@ omp_get_targets (gnutls_session_t* session, const char* id, int tasks,
   const char* status_code;
   int ret;
 
+  (void) include_rcfile;
   if (id == NULL)
     {
       if (openvas_server_sendf (session,
@@ -1180,14 +1457,10 @@ omp_get_report_ext (gnutls_session_t* session,
                             "<get_reports"
                             " report_id=\"%s\""
                             " format_id=\"%s\""
-                            " sort_field=\"%s\""
-                            " sort_order=\"%s\""
-                            " levels=\"%s\""
-                            " first_result=\"%i\""
-                            " max_results=\"%i\""
                             " host_first_result=\"%i\""
                             " host_max_results=\"%i\""
-                            " autofp=\"%i\""
+                            "%s%s%s"
+                            "%s%s%s"
                             "%s%s%s"
                             "%s%s%s"
                             "%s%s%s"
@@ -1203,15 +1476,11 @@ omp_get_report_ext (gnutls_session_t* session,
                             "%s%s%s%s%s%s%s/>",
                             opts.report_id,
                             opts.format_id,
-                            opts.sort_field,
-                            opts.sort_order,
-                            opts.levels,
-                            opts.first_result,
-                            opts.max_results,
                             opts.host_first_result,
                             opts.host_max_results,
-                            opts.autofp,
                             OMP_FMT_STRING_ATTRIB (opts, type),
+                            OMP_FMT_STRING_ATTRIB (opts, filter),
+                            OMP_FMT_STRING_ATTRIB (opts, filt_id),
                             OMP_FMT_STRING_ATTRIB (opts, host),
                             OMP_FMT_STRING_ATTRIB (opts, pos),
                             OMP_FMT_STRING_ATTRIB (opts, timezone),
@@ -1322,7 +1591,7 @@ omp_create_target_ext (gnutls_session_t* session,
                        omp_create_target_opts_t opts,
                        gchar** id)
 {
-  gchar *comment, *ssh, *smb, *esxi, *port_range, *start;
+  gchar *comment, *ssh, *smb, *esxi, *snmp, *port_range, *start;
   gchar *exclude_hosts, *alive_tests;
   int ret;
 
@@ -1388,6 +1657,12 @@ omp_create_target_ext (gnutls_session_t* session,
   else
     esxi = NULL;
 
+  if (opts.snmp_credential_id)
+    snmp = g_markup_printf_escaped ("<snmp_credential id=\"%s\"/>",
+                                    opts.snmp_credential_id);
+  else
+    snmp = NULL;
+
   if (opts.port_range)
     port_range = g_markup_printf_escaped ("<port_range>%s</port_range>",
                                           opts.port_range);
@@ -1396,7 +1671,7 @@ omp_create_target_ext (gnutls_session_t* session,
 
   /* Send the request. */
   ret = openvas_server_sendf (session,
-                              "%s%s%s%s%s%s%s%s"
+                              "%s%s%s%s%s%s%s%s%s"
                               "<reverse_lookup_only>%d</reverse_lookup_only>"
                               "<reverse_lookup_unify>%d</reverse_lookup_unify>"
                               "</create_target>",
@@ -1406,6 +1681,7 @@ omp_create_target_ext (gnutls_session_t* session,
                               ssh ? ssh : "",
                               smb ? smb : "",
                               esxi ? esxi : "",
+                              snmp ? snmp : "",
                               port_range ? port_range : "",
                               comment ? comment : "",
                               opts.reverse_lookup_only,
@@ -1501,23 +1777,23 @@ omp_create_lsc_credential (gnutls_session_t* session,
     {
       if (comment)
         ret = openvas_server_sendf_xml_quiet (session,
-                                              "<create_lsc_credential>"
+                                              "<create_credential>"
                                               "<name>%s</name>"
                                               "<login>%s</login>"
                                               "<password>%s</password>"
                                               "<comment>%s</comment>"
-                                              "</create_lsc_credential>",
+                                              "</create_credential>",
                                               name,
                                               login,
                                               password,
                                               comment);
       else
         ret = openvas_server_sendf_xml_quiet (session,
-                                              "<create_lsc_credential>"
+                                              "<create_credential>"
                                               "<name>%s</name>"
                                               "<login>%s</login>"
                                               "<password>%s</password>"
-                                              "</create_lsc_credential>",
+                                              "</create_credential>",
                                               name,
                                               login,
                                               password);
@@ -1526,20 +1802,20 @@ omp_create_lsc_credential (gnutls_session_t* session,
     {
       if (comment)
         ret = openvas_server_sendf_xml (session,
-                                        "<create_lsc_credential>"
+                                        "<create_credential>"
                                         "<name>%s</name>"
                                         "<login>%s</login>"
                                         "<comment>%s</comment>"
-                                        "</create_lsc_credential>",
+                                        "</create_credential>",
                                         name,
                                         login,
                                         comment);
       else
         ret = openvas_server_sendf_xml (session,
-                                        "<create_lsc_credential>"
+                                        "<create_credential>"
                                         "<name>%s</name>"
                                         "<login>%s</login>"
-                                        "</create_lsc_credential>",
+                                        "</create_credential>",
                                         name,
                                         login);
     }
@@ -1579,7 +1855,7 @@ omp_create_lsc_credential_key (gnutls_session_t *session,
 
   if (comment)
     ret = openvas_server_sendf_xml (session,
-                                    "<create_lsc_credential>"
+                                    "<create_credential>"
                                     "<name>%s</name>"
                                     "<login>%s</login>"
                                     "<key>"
@@ -1587,7 +1863,7 @@ omp_create_lsc_credential_key (gnutls_session_t *session,
                                     "<private>%s</private>"
                                     "</key>"
                                     "<comment>%s</comment>"
-                                    "</create_lsc_credential>",
+                                    "</create_credential>",
                                     name,
                                     login,
                                     passphrase ? passphrase : "",
@@ -1595,14 +1871,14 @@ omp_create_lsc_credential_key (gnutls_session_t *session,
                                     comment);
   else
     ret = openvas_server_sendf_xml (session,
-                                    "<create_lsc_credential>"
+                                    "<create_credential>"
                                     "<name>%s</name>"
                                     "<login>%s</login>"
                                     "<key>"
                                     "<phrase>%s</phrase>"
                                     "<private>%s</private>"
                                     "</key>"
-                                    "</create_lsc_credential>",
+                                    "</create_credential>",
                                     name,
                                     login,
                                     passphrase ? passphrase : "",
@@ -1632,7 +1908,7 @@ omp_create_lsc_credential_ext (gnutls_session_t* session,
                                omp_create_lsc_credential_opts_t opts,
                                gchar** id)
 {
-  gchar *comment, *pass, *start;
+  gchar *comment, *pass, *start, *snmp_elems;
   int ret;
 
   /* Create the OMP request. */
@@ -1640,7 +1916,7 @@ omp_create_lsc_credential_ext (gnutls_session_t* session,
   if (opts.login == NULL)
     return -1;
 
-  start = g_markup_printf_escaped ("<create_lsc_credential>"
+  start = g_markup_printf_escaped ("<create_credential>"
                                    "<name>%s</name>"
                                    "<login>%s</login>",
                                    opts.name ? opts.name : "unnamed",
@@ -1672,13 +1948,33 @@ omp_create_lsc_credential_ext (gnutls_session_t* session,
         pass = NULL;
     }
 
+  if (opts.community && opts.auth_algorithm && opts.privacy_password
+      && opts.privacy_algorithm)
+    snmp_elems = g_markup_printf_escaped ("<community>"
+                                          "%s"
+                                          "</community>"
+                                          "<auth_algorithm>"
+                                          "%s"
+                                          "</auth_algorithm>"
+                                          "<privacy>"
+                                          "<password>%s</password>"
+                                          "<algorithm>%s</algorithm>"
+                                          "</privacy>",
+                                          opts.community,
+                                          opts.auth_algorithm,
+                                          opts.privacy_password,
+                                          opts.privacy_algorithm);
+  else
+    snmp_elems = NULL;
+
   /* Send the request. */
 
   ret = openvas_server_sendf (session,
-                              "%s%s%s</create_lsc_credential>",
+                              "%s%s%s%s</create_credential>",
                               start,
                               comment ? comment : "",
-                              pass ? pass : "");
+                              pass ? pass : "",
+                              snmp_elems ? snmp_elems : "");
 
   g_free (start);
   g_free (comment);
@@ -1698,7 +1994,7 @@ omp_create_lsc_credential_ext (gnutls_session_t* session,
  * @brief Delete a LSC credential.
  *
  * @param[in]   session     Pointer to GNUTLS session.
- * @param[in]   uuid        UUID of LSC credential.
+ * @param[in]   id          UUID of LSC credential.
  * @param[in]   opts        Struct containing the options to apply.
  *
  * @return 0 on success, -1 or OMP response code on error.
@@ -1709,7 +2005,7 @@ omp_delete_lsc_credential_ext (gnutls_session_t* session,
                                omp_delete_opts_t opts)
 {
   if (openvas_server_sendf (session,
-                            "<delete_lsc_credential lsc_credential_id=\"%s\""
+                            "<delete_credential credential_id=\"%s\""
                             " ultimate=\"%d\"/>",
                             id, opts.ultimate)
       == -1)
@@ -1792,71 +2088,36 @@ omp_get_system_reports_ext (gnutls_session_t* session,
                             entity_t *reports)
 {
   const char* status_code;
-  gchar *slave_id_attrib;
+  GString *request;
   int ret;
 
-  slave_id_attrib = opts.slave_id ? g_strdup_printf (" slave_id=\"%s\"",
-                                                     opts.slave_id)
-                                  : g_strdup ("");
+  request = g_string_new ("<get_system_reports");
+
+  if (opts.slave_id)
+    xml_string_append (request, " slave_id=\"%s\"", opts.slave_id);
+
+  if (opts.name)
+    xml_string_append (request, " name=\"%s\"", opts.name);
+
+  if (opts.duration)
+    xml_string_append (request, " duration=\"%s\"", opts.duration);
+
+  if (opts.start_time)
+    xml_string_append (request, " start_time=\"%s\"", opts.start_time);
+
+  if (opts.end_time)
+    xml_string_append (request, " end_time=\"%s\"", opts.end_time);
+
+  g_string_append (request, "/>");
 
   /* Create the OMP request. */
 
-  if (opts.name && opts.duration)
+  if (openvas_server_sendf (session, "%s", request->str) == -1)
     {
-      if (openvas_server_sendf (session,
-                                "<get_system_reports%s"
-                                " name=\"%s\""
-                                " duration=\"%s\""
-                                " brief=\"%i\"/>",
-                                slave_id_attrib,
-                                opts.name,
-                                opts.duration,
-                                opts.brief)
-          == -1)
-        {
-          g_free (slave_id_attrib);
-          return -1;
-        }
-    }
-  else if (opts.name)
-    {
-      if (openvas_server_sendf (session,
-                                "<get_system_reports%s"
-                                " name=\"%s\""
-                                " brief=\"%i\"/>",
-                                slave_id_attrib,
-                                opts.name,
-                                opts.brief)
-          == -1)
-        {
-          g_free (slave_id_attrib);
-          return -1;
-        }
-    }
-  else if (opts.duration)
-    {
-      if (openvas_server_sendf (session,
-                                "<get_system_reports%s"
-                                " duration=\"%s\""
-                                " brief=\"%i\"/>",
-                                slave_id_attrib,
-                                opts.duration,
-                                opts.brief)
-          == -1)
-        {
-          g_free (slave_id_attrib);
-          return -1;
-        }
-    }
-  else if (openvas_server_sendf (session,
-                                 "<get_system_reports%s brief=\"%i\"/>",
-                                 slave_id_attrib,
-                                 opts.brief)
-           == -1)
-    {
-      g_free (slave_id_attrib);
+      g_string_free (request, 1);
       return -1;
     }
+  g_string_free (request, 1);
 
   /* Read the response. */
 
