@@ -289,6 +289,9 @@ handle_start_element (GMarkupParseContext * context, const gchar * element_name,
 {
   entity_t entity;
   context_data_t *data = (context_data_t *) user_data;
+
+  (void) context;
+  (void) error;
   if (data->current)
     {
       entity_t current = (entity_t) data->current->data;
@@ -319,6 +322,10 @@ handle_end_element (GMarkupParseContext * context, const gchar * element_name,
                     gpointer user_data, GError ** error)
 {
   context_data_t *data = (context_data_t *) user_data;
+
+  (void) context;
+  (void) error;
+  (void) element_name;
   assert (data->current && data->first);
   if (data->current == data->first)
     {
@@ -353,6 +360,10 @@ handle_text (GMarkupParseContext * context, const gchar * text, gsize text_len,
              gpointer user_data, GError ** error)
 {
   context_data_t *data = (context_data_t *) user_data;
+
+  (void) context;
+  (void) text_len;
+  (void) error;
   entity_t current = (entity_t) data->current->data;
   if (current->text)
     {
@@ -374,6 +385,8 @@ handle_text (GMarkupParseContext * context, const gchar * text, gsize text_len,
 void
 handle_error (GMarkupParseContext * context, GError * error, gpointer user_data)
 {
+  (void) context;
+  (void) user_data;
   g_message ("   Error: %s\n", error->message);
 }
 
@@ -475,7 +488,7 @@ try_read_entity_and_string (gnutls_session_t * session, int timeout,
                 continue;
               if ((timeout > 0) && (count == GNUTLS_E_AGAIN))
                 {
-                  /* Server still busy, either timeout and try read again. */
+                  /* Server still busy, either timeout or try read again. */
                   if ((timeout - (time (NULL) - last_time))
                       <= 0)
                     {
@@ -568,6 +581,7 @@ try_read_entity_and_string (gnutls_session_t * session, int timeout,
             *string_return = string;
           if (timeout > 0)
             fcntl (socket, F_SETFL, 0L);
+          g_slist_free (context_data.first);
           g_markup_parse_context_free (xml_context);
           return 0;
         }
@@ -586,8 +600,8 @@ try_read_entity_and_string (gnutls_session_t * session, int timeout,
 /**
  * @brief Try read an XML entity tree from the manager.
  *
- * @param[in]   session   Pointer to GNUTLS session.
- * @param[in]   timeout   Seconds or server idle time before giving up.  0 to
+ * @param[in]   connection  Connection.
+ * @param[in]   timeout   Server idle time before giving up, in seconds.  0 to
  *                        wait forever.
  * @param[out]  entity    Pointer to an entity tree.
  * @param[out]  string    An optional return location for the text read
@@ -600,12 +614,235 @@ try_read_entity_and_string (gnutls_session_t * session, int timeout,
  * @return 0 success, -1 read error, -2 parse error, -3 end of file, -4 timeout.
  */
 int
+try_read_entity_and_string_c (openvas_connection_t *connection, int timeout,
+                              entity_t * entity, GString ** string_return)
+{
+  GMarkupParser xml_parser;
+  GError *error = NULL;
+  GMarkupParseContext *xml_context;
+  GString *string;
+  time_t last_time;
+  /* Buffer for reading from the manager. */
+  char buffer_start[BUFFER_SIZE];
+  /* End of the manager reading buffer. */
+  char *buffer_end = buffer_start + BUFFER_SIZE;
+
+  if (connection->tls)
+    return try_read_entity_and_string (&connection->session, timeout, entity,
+                                       string_return);
+
+  /* Record the start time. */
+
+  if (time (&last_time) == -1)
+    {
+      g_warning ("   failed to get current time: %s\n",
+                 strerror (errno));
+      return -1;
+    }
+
+  if (timeout > 0)
+    {
+      /* Turn off blocking. */
+
+      if (fcntl (connection->socket, F_SETFL, O_NONBLOCK) == -1)
+        return -1;
+    }
+
+  /* Setup return arg. */
+
+  if (string_return == NULL)
+    string = NULL;
+  else if (*string_return == NULL)
+    string = g_string_new ("");
+  else
+    string = *string_return;
+
+  /* Create the XML parser. */
+
+  xml_parser.start_element = handle_start_element;
+  xml_parser.end_element = handle_end_element;
+  xml_parser.text = handle_text;
+  xml_parser.passthrough = NULL;
+  xml_parser.error = handle_error;
+
+  context_data_t context_data;
+  context_data.done = FALSE;
+  context_data.first = NULL;
+  context_data.current = NULL;
+
+  /* Setup the XML context. */
+
+  xml_context =
+    g_markup_parse_context_new (&xml_parser, 0, &context_data, NULL);
+
+  /* Read and parse, until encountering end of file or error. */
+
+  while (1)
+    {
+      int count;
+      while (1)
+        {
+          g_debug ("   asking for %i\n", (int) (buffer_end - buffer_start));
+          count = read (connection->socket, buffer_start,
+                        buffer_end - buffer_start);
+          if (count < 0)
+            {
+              if (errno == EINTR)
+                /* Interrupted, try read again. */
+                continue;
+              if (timeout > 0)
+                {
+                  if ((errno == EAGAIN) || (errno == EAGAIN))
+                    {
+                      /* Server still busy, either timeout or try read again. */
+                      if ((timeout - (time (NULL) - last_time))
+                          <= 0)
+                        {
+                          g_warning ("   timeout\n");
+                          fcntl (connection->socket, F_SETFL, 0L);
+                          g_markup_parse_context_free (xml_context);
+                          return -4;
+                        }
+                    }
+                  continue;
+                }
+              if (context_data.first && context_data.first->data)
+                {
+                  free_entity (context_data.first->data);
+                  g_slist_free_1 (context_data.first);
+                }
+              if (string && *string_return == NULL)
+                g_string_free (string, TRUE);
+              if (timeout > 0)
+                fcntl (connection->socket, F_SETFL, 0L);
+              g_markup_parse_context_free (xml_context);
+              return -1;
+            }
+          if (count == 0)
+            {
+              /* End of file. */
+              g_markup_parse_context_end_parse (xml_context, &error);
+              if (error)
+                {
+                  g_warning ("   End error: %s\n", error->message);
+                  g_error_free (error);
+                }
+              if (context_data.first && context_data.first->data)
+                {
+                  free_entity (context_data.first->data);
+                  g_slist_free_1 (context_data.first);
+                }
+              if (string && *string_return == NULL)
+                g_string_free (string, TRUE);
+              if (timeout > 0)
+                fcntl (connection->socket, F_SETFL, 0L);
+              g_markup_parse_context_free (xml_context);
+              return -3;
+            }
+          break;
+        }
+
+      g_debug ("<= %.*s\n", (int) count, buffer_start);
+
+      if (string)
+        g_string_append_len (string, buffer_start, count);
+
+      g_markup_parse_context_parse (xml_context, buffer_start, count, &error);
+      if (error)
+        {
+          g_error_free (error);
+          // FIX there may be multiple entries in list
+          if (context_data.first && context_data.first->data)
+            {
+              free_entity (context_data.first->data);
+              g_slist_free_1 (context_data.first);
+            }
+          if (string && *string_return == NULL)
+            g_string_free (string, TRUE);
+          if (timeout > 0)
+            fcntl (connection->socket, F_SETFL, 0L);
+          g_markup_parse_context_free (xml_context);
+          return -2;
+        }
+      if (context_data.done)
+        {
+          g_markup_parse_context_end_parse (xml_context, &error);
+          if (error)
+            {
+              g_warning ("   End error: %s\n", error->message);
+              g_error_free (error);
+              if (context_data.first && context_data.first->data)
+                {
+                  free_entity (context_data.first->data);
+                  g_slist_free_1 (context_data.first);
+                }
+              if (timeout > 0)
+                fcntl (connection->socket, F_SETFL, 0L);
+              g_markup_parse_context_free (xml_context);
+              return -2;
+            }
+          *entity = (entity_t) context_data.first->data;
+          if (string)
+            *string_return = string;
+          if (timeout > 0)
+            fcntl (connection->socket, F_SETFL, 0L);
+          g_markup_parse_context_free (xml_context);
+          return 0;
+        }
+
+      if ((timeout > 0) && (time (&last_time) == -1))
+        {
+          g_warning ("   failed to get current time (1): %s\n",
+                     strerror (errno));
+          fcntl (connection->socket, F_SETFL, 0L);
+          g_markup_parse_context_free (xml_context);
+          return -1;
+        }
+    }
+}
+
+/**
+ * @brief Try read an XML entity tree from the manager.
+ *
+ * @param[in]   session          Pointer to GNUTLS session.
+ * @param[out]  entity           Pointer to an entity tree.
+ * @param[out]  string_return    An optional return location for the text read
+ *                               from the session.  If NULL then it simply
+ *                               remains NULL.  If a pointer to NULL then it points
+ *                               to a freshly allocated GString on successful return.
+ *                               Otherwise it points to an existing GString onto
+ *                               which the text is appended.
+ *
+ * @return 0 success, -1 read error, -2 parse error, -3 end of file.
+ */
+int
 read_entity_and_string (gnutls_session_t * session, entity_t * entity,
                         GString ** string_return)
 {
   return try_read_entity_and_string (session, 0, entity, string_return);
 }
 
+/**
+ * @brief Try read an XML entity tree from the manager.
+ *
+ * @param[in]   connection       Connection.
+ * @param[out]  entity           Pointer to an entity tree.
+ * @param[out]  string_return    An optional return location for the text read
+ *                               from the session.  If NULL then it simply
+ *                               remains NULL.  If a pointer to NULL then it points
+ *                               to a freshly allocated GString on successful return.
+ *                               Otherwise it points to an existing GString onto
+ *                               which the text is appended.
+ *
+ * @return 0 success, -1 read error, -2 parse error, -3 end of file.
+ */
+int
+read_entity_and_string_c (openvas_connection_t *connection, entity_t * entity,
+                          GString ** string_return)
+{
+  return try_read_entity_and_string_c (connection, 0, entity, string_return);
+}
+
 /**
  * @brief Read an XML entity tree from the manager.
  *
@@ -638,6 +875,37 @@ read_entity_and_text (gnutls_session_t * session, entity_t * entity,
   return read_entity_and_string (session, entity, NULL);
 }
 
+/**
+ * @brief Read an XML entity tree from the manager.
+ *
+ * @param[in]   connection  Connection.
+ * @param[out]  entity      Entity tree.
+ * @param[out]  text      A pointer to a pointer, at which to store the
+ *                        address of a newly allocated string holding the
+ *                        text read from the session, if the text is required,
+ *                        else NULL.
+ *
+ * @return 0 success, -1 read error, -2 parse error, -3 end of file.
+ */
+int
+read_entity_and_text_c (openvas_connection_t *connection, entity_t *entity,
+                        char **text)
+{
+  if (text)
+    {
+      GString *string = NULL;
+      int ret = read_entity_and_string_c (connection, entity, &string);
+      if (ret)
+        {
+          if (string)
+            g_string_free (string, TRUE);
+          return ret;
+        }
+      *text = g_string_free (string, FALSE);
+      return 0;
+    }
+  return read_entity_and_string_c (connection, entity, NULL);
+}
 
 /**
  * @brief Read entity and text. Free the entity immediately.
@@ -659,6 +927,26 @@ read_string (gnutls_session_t * session, GString ** string)
   return ret;
 }
 
+/**
+ * @brief Read entity and text. Free the entity immediately.
+ *
+ * @param[in]   connection  Connection.
+ * @param[out]  string      Return location for the string.
+ *
+ * @return 0 success, -1 read error, -2 parse error, -3 end of file.
+ */
+int
+read_string_c (openvas_connection_t *connection, GString **string)
+{
+  int ret = 0;
+  entity_t entity;
+
+  if (!(ret = read_entity_and_string_c (connection, &entity, string)))
+    free_entity (entity);
+
+  return ret;
+}
+
 /**
  * @brief Try read an XML entity tree from the manager.
  *
@@ -675,6 +963,23 @@ try_read_entity (gnutls_session_t * session, int timeout, entity_t * entity)
   return try_read_entity_and_string (session, timeout, entity, NULL);
 }
 
+/**
+ * @brief Try read an XML entity tree from the manager.
+ *
+ * @param[in]   connection  Connection.
+ * @param[in]   timeout     Server idle time before giving up, in seconds.  0 to
+ *                          wait forever.
+ * @param[out]  entity      Pointer to an entity tree.
+ *
+ * @return 0 success, -1 read error, -2 parse error, -3 end of file, -4 timeout.
+ */
+int
+try_read_entity_c (openvas_connection_t *connection, int timeout,
+                   entity_t * entity)
+{
+  return try_read_entity_and_string_c (connection, timeout, entity, NULL);
+}
+
 /**
  * @brief Read an XML entity tree from the manager.
  *
@@ -689,6 +994,20 @@ read_entity (gnutls_session_t * session, entity_t * entity)
   return try_read_entity (session, 0, entity);
 }
 
+/**
+ * @brief Read an XML entity tree from the manager.
+ *
+ * @param[in]   session   Pointer to GNUTLS session.
+ * @param[out]  entity    Pointer to an entity tree.
+ *
+ * @return 0 success, -1 read error, -2 parse error, -3 end of file.
+ */
+int
+read_entity_c (openvas_connection_t *connection, entity_t *entity)
+{
+  return try_read_entity_c (connection, 0, entity);
+}
+
 /**
  * @brief Read an XML entity tree from a string.
  *
@@ -870,6 +1189,7 @@ print_entity (FILE * stream, entity_t entity)
 static void
 foreach_print_attribute_format (gpointer name, gpointer value, gpointer none)
 {
+  (void) none;
   printf (" %s=\"%s\"", (char *) name, (char *) value);
 }
 
@@ -1042,3 +1362,138 @@ xml_string_append (GString *xml, const char *format, ...)
   g_string_append (xml, piece);
   g_free (piece);
 }
+
+/* XML file utilities */
+
+/**
+ * @brief Handle the opening tag of an element in an XML search.
+ *
+ * @param[in]   ctx               The parse context.
+ * @param[in]   element_name      The name of the element.
+ * @param[in]   attribute_names   NULL-terminated array of attribute names.
+ * @param[in]   attribute_values  NULL-terminated array of attribute values.
+ * @param[in]   data              The search data struct.
+ * @param[out]  error             Pointer to error output location.
+ */
+static void
+xml_search_handle_start_element (GMarkupParseContext *ctx,
+                                 const gchar *element_name,
+                                 const gchar **attribute_names,
+                                 const gchar **attribute_values,
+                                 gpointer data,
+                                 GError **error)
+{
+  (void) ctx;
+  (void) error;
+
+  xml_search_data_t *search_data = ((xml_search_data_t*) data);
+
+  if (strcmp (element_name, search_data->find_element) == 0
+      && search_data->found == 0)
+    {
+      g_debug ("%s: Found element <%s>", __FUNCTION__, element_name);
+
+      if (search_data->find_attributes
+          && g_hash_table_size (search_data->find_attributes))
+        {
+          int index;
+          GHashTable *found_attributes;
+          found_attributes = g_hash_table_new_full (g_str_hash, g_str_equal,
+                                                    NULL, NULL);
+          index = 0;
+          while (attribute_names[index])
+            {
+              gchar *searched_value;
+              searched_value
+                = g_hash_table_lookup (search_data->find_attributes,
+                                       attribute_names[index]);
+              if (searched_value
+                  && strcmp (searched_value, attribute_values[index]) == 0)
+                {
+                  g_debug ("%s: Found attribute %s=\"%s\"",
+                           __FUNCTION__,
+                           attribute_names[index], searched_value);
+                  g_hash_table_add (found_attributes, searched_value);
+                }
+              index ++;
+            }
+          g_debug ("%s: Found %d of %d attributes",
+                   __FUNCTION__,
+                   g_hash_table_size (found_attributes),
+                   g_hash_table_size (search_data->find_attributes));
+
+          if (g_hash_table_size (found_attributes)
+              == g_hash_table_size (search_data->find_attributes))
+            {
+              search_data->found = 1;
+            }
+
+          g_hash_table_destroy (found_attributes);
+        }
+      else
+        {
+          search_data->found = 1;
+        }
+    }
+}
+
+#define XML_FILE_BUFFER_SIZE 1048576
+int
+/**
+ * @brief Tests if an XML file contains an element with given attributes.
+ *
+ * @param[in]   file_path         Path of the XML file.
+ * @param[in]   find_element      Name of the element to find.
+ * @param[in]   find_attributes   GHashTable of attributes to find.
+ *
+ * @return  1 if element was found, 0 if not.
+ */
+find_element_in_xml_file (gchar *file_path, gchar *find_element,
+                          GHashTable* find_attributes)
+{
+  gchar buffer[XML_FILE_BUFFER_SIZE];
+  FILE *file;
+  int read_len;
+  GMarkupParser xml_parser;
+  GMarkupParseContext *xml_context;
+  xml_search_data_t search_data;
+  GError *error = NULL;
+
+  search_data.find_element = find_element;
+  search_data.find_attributes = find_attributes;
+  search_data.found = 0;
+
+  /* Create the XML parser. */
+  xml_parser.start_element = xml_search_handle_start_element;
+  xml_parser.end_element = NULL;
+  xml_parser.text = NULL;
+  xml_parser.passthrough = NULL;
+  xml_parser.error = NULL;
+  xml_context = g_markup_parse_context_new
+                 (&xml_parser,
+                  0,
+                  &search_data,
+                  NULL);
+
+  file = fopen (file_path, "r");
+  if (file == NULL)
+    {
+      g_markup_parse_context_free (xml_context);
+      g_warning ("%s: Failed to open '%s':", __FUNCTION__, strerror (errno));
+      return 0;
+    }
+
+  while ((read_len = fread (&buffer, sizeof(char), XML_FILE_BUFFER_SIZE, file))
+         && g_markup_parse_context_parse
+              (xml_context, buffer, read_len, &error)
+         && error == NULL)
+    {
+    }
+  g_markup_parse_context_end_parse (xml_context, &error);
+
+  fclose (file);
+
+  g_markup_parse_context_free (xml_context);
+  return search_data.found;
+}
+#undef XML_FILE_BUFFER_SIZE
